@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -55,6 +55,7 @@ function AcceptDeny(showdetail) {
                         $("acceptdeny_comment3").value, function() {
                             var grid = AcceptDeny.grid;
                             grid.deleteIDs(grid.getSelectedIDs());
+                            $("acceptdeny_comment3").value=""; // bug #15388
                             if (!grid.storage.ids.length) {
                                 Self.removeDomEvents();
                                 AcceptDeny.hide();
@@ -158,7 +159,29 @@ AcceptDeny.prototype = {
             var grid = AcceptDeny.grid;
             if (!grid) {
                 var defaultClear = LiveGrid.makeClear("");
-                grid = AcceptDeny.grid = new LiveGrid([{
+                grid = AcceptDeny.grid = new LiveGrid([
+                {
+                	width: "30px",
+                	style: "padding: 0px, margin: 0px",
+                	text: "&#x00a0;",
+                	set: function(div, data) {
+                        var src = getFullImgSrc("img/calendar/mod_calendar.gif");
+                        if (data.module && data.module == "tasks") {
+                        	src = getFullImgSrc("img/tasks/mod_tasks.gif");
+                        }
+                        if (!div.firstChild) {
+                            div.appendChild(newnode("img", {height : "24px", width : "24px"}, { src: getFullImgSrc("img/dummy.gif"), align: "absmiddle"}));
+                        }
+                        div.firstChild.src = src;
+                    },
+                    clear: function(div) {
+                        if (!div.firstChild) {
+                            div.appendChild(newnode("img", {height : "24px", width : "24px"}, { src: getFullImgSrc("img/dummy.gif"), align: "absmiddle"}));
+                        } else {
+                            div.firstChild.src = getFullImgSrc("img/dummy.gif");
+                        }
+                    }
+                },{
                     i18n: "description"/*i18n context*/, text: "Title"/*i18n*/,
                     clear: defaultClear,
                     set: function(div, data) {
@@ -190,6 +213,19 @@ AcceptDeny.prototype = {
                     setDisabled($("acceptdeny_accept"), count == 0);
                     setDisabled($("acceptdeny_decline"), count == 0);
                     setDisabled($("acceptdeny_tentative"), count == 0);
+                    
+                    // change button text - either it's an appointment or a task 
+                    var ids = grid.getSelectedIDs();
+                    if (ids.length != 1) return;
+                    grid.storage.newIterate(ids, emptyFunction,
+                        function(i, object) {
+                    		if (!object.module) return;
+                    		var butText = _("Show in calendar");
+                    		if (object.module == "tasks") {
+                    			butText = _("Show in task");
+                    		}
+                    		$("acceptdeny_show-button").firstChild.data = butText;
+                        });
                 });
                 AcceptDeny.storage = new Storage(0, [], 0, 0, 0, 0,
                     function(x) { return x.objectid; });
@@ -205,12 +241,14 @@ AcceptDeny.prototype = {
                     if (ids.length != 1) return;
                     grid.storage.newIterate(ids, emptyFunction,
                         function(i, object) {
-                            activeDay = object.startdate.getUTCDate();
-                            activeMonth = object.startdate.getUTCMonth();
-                            activeYear = object.startdate.getUTCFullYear();
-                            activemodule = "calendar";
+                    		activemodule = object.module || "calendar";
+                    		if (activemodule == "calendar") {
+		                        activeDay = object.startdate.getUTCDate();
+		                        activeMonth = object.startdate.getUTCMonth();
+		                        activeYear = object.startdate.getUTCFullYear();
+                    		}
                             setActiveFolder(object.folder_id, null, true);
-                            triggerEvent("OX_Switch_Module", "calendar",
+                            triggerEvent("OX_Switch_Module", activemodule,
                                          "newfolder");
                             $("disable_background_window").style.width = 0;
                             $("disable_background_window").style.height = 0;
@@ -239,17 +277,30 @@ AcceptDeny.prototype = {
 }
 
 function acceptdeny_updateConfirm(objects, status, message, callback) {	
+    var join = new Join(function() {
+        json.put(AjaxRoot + "/multiple?session=" + session, requests, null,
+                 finalCallback, finalCallback);
+    });
+    var last = join.add();
     var requests = new Array();
     for (var i = 0; i < objects.length; i++) {
-        var object = objects[i];			
-        requests.push({
-            module: object.module, action: "confirm",
-            folder: object.folder_id, id: object.objectid,
-            data: { confirmmessage: message, confirmation: status }
-        });
+        oMainFolderTree.cache.get_folder(objects[i].folder_id,
+            join.add((function(object) {
+                return function(folder) {
+                    var owner = folder.oxfolder.data.type == 3 ?
+                        folder.oxfolder.data.created_by :
+                        configGetKey("identifier");
+                    requests.push({
+                        module: object.module, action: "confirm",
+                        folder: object.folder_id, id: object.objectid,
+                        data: { id: owner, confirmmessage: message,
+                                confirmation: status }
+                    });
+                };
+            })(objects[i])));
     }
-    json.put(AjaxRoot + "/multiple?session=" + session, requests, null, f, f);
-    function f(resp) {
+    last();
+    function finalCallback(resp) {
         // TODO CHECK ERRORS
         acceptdeny_update_objects_in_cache(requests,
             acceptdeny_get_timestamp(resp));			
@@ -290,67 +341,68 @@ function acceptdeny_update_objects_in_cache(objects, timestamp) {
 register("OX_Configuration_Loaded_Complete",acceptdeny_start);
 
 function acceptdeny_start() {	
-	function acceptdeny_fillCalendar(response) 
-	{
+	function acceptdeny_fill(response) {
 		var conarray=new Array();
 		var constrings=new Object();
-		contimestamp=response.timestamp;
-        if(!response.data || !response.data.length) return;
-		response=response.data;
-		for(var i=0;i<response.length;i++) {
-			var newobject=new Object();
-			newobject.id=response[i][0];
-			newobject.folder_id=response[i][1];	
-			newobject.start_date=response[i][2];
-			newobject.end_date=response[i][3];
-			newobject.users=response[i][5];
-			newobject.title=response[i][6];
-			newobject.created_by=response[i][7];	
-			newobject.location=response[i][8];
-
-
-			for(var i2=0;i2<newobject.users.length;i2++) {
-				if(newobject.users[i2].id == configGetKey("identifier")) {
-					if(newobject.users[i2].confirmation == 0) {
-						if(!constrings[newobject.folder_id+":"+newobject.id]) {
-							constrings[newobject.folder_id+":"+newobject.id]=true;
-							conarray.push(newobject);		
+        for (var ia=0; ia<response.length; ia++) {
+        	if (!response[ia].data || !response[ia].data.length) continue;
+			var data = response[ia].data;
+			contimestamp = data.timestamp;
+			for (var i=0; i<data.length; i++) {
+				var newobject=new Object();
+				newobject.id=data[i][0];
+				newobject.folder_id=data[i][1];	
+				newobject.start_date=data[i][2];
+				newobject.end_date=data[i][3];
+				newobject.users=data[i][5];
+				newobject.title=data[i][6];
+				newobject.created_by=data[i][7];	
+				newobject.location=data[i][8];
+				newobject.module = (ia == 0 ? "calendar" : "tasks");
+				for(var i2=0; i2<newobject.users.length; i2++) {					
+					if (newobject.users[i2].id == configGetKey("identifier")) {
+						if (newobject.users[i2].confirmation == 0) {
+							if(!constrings[newobject.folder_id+":"+newobject.id]) {
+								constrings[newobject.folder_id+":"+newobject.id]=true;
+								conarray.push(newobject);		
+							}
 						}
+						break;
 					}
-					break;
 				}
-			}
-		}	
+			}	
+        }
 		showAllConfirmation(conarray);
 	}
-	function acceptdeny_fillTasks(response) {
-	}
 	var checkconfirmation=true;
-	var calendarstring;
 	var columns="1,20,201,202,209,221,200,2"
-	var taskstring;
 	var confirmtimestamp=0;
-	if(configContainsKey("gui.global.confirmpopup")) {
-		checkconfirmation=configGetKey("gui.global.confirmpopup")
+	if (configContainsKey("gui.global.confirmtimestamp")) {
+		confirmtimestamp = configGetKey("gui.global.confirmtimestamp");
 	}
-	if(configContainsKey("gui.global.confirmtimestamp")) {
-		confirmtimestamp=configGetKey("gui.global.confirmtimestamp")
-	}
-	if(checkconfirmation) {
-		calendarstring=AjaxRoot + "/calendar?action=updates&session="+session+"&start="+(new Date().getTime())+"&end="+(new Date().getTime()+360000*24*365*5)+"&timestamp="+confirmtimestamp+"&ignore=deleted&columns="+columns+",400";
-		taskstring=AjaxRoot + "/tasks?action=updates&session="+session+"&start="+(new Date().getTime())+"&end="+(new Date().getTime()+360000*24*365*5)+"&timestamp="+confirmtimestamp+"&ignore=deleted&columns="+columns;
-		var json=new JSON();
-		if(configGetKey("modules.calendar.module"))
-			json.get(calendarstring,null,acceptdeny_fillCalendar);
+	if (configContainsKey("gui.global.confirmpopup") && 
+			configGetKey("gui.global.confirmpopup") == true) {
+		var startDate = new Date().getTime();
+		var endDate = startDate+360000*24*365*5;
+		var requests = [];
+		if (configGetKey("modules.calendar.module")) {
+			requests.push( { module: "calendar", action: "updates", start: startDate, end: endDate, timestamp: confirmtimestamp, ignore: "deleted", columns: columns + ",400" } )
+		}
+		if (configGetKey("modules.tasks.module")) {
+			requests.push( { module: "tasks", action: "updates", folder: configGetKey("folder.tasks"), start: startDate, end: endDate, timestamp: confirmtimestamp, ignore: "deleted", columns: columns } )
+		}
+		if (requests.length) {
+			(new JSON).put(AjaxRoot + "/multiple?session=" + session, requests, null, acceptdeny_fill);
+		}
 	}
 }
 var globalconfirm= new AcceptDeny(true);
 var contimestamp;
 
-function showAllConfirmation(acceptdenyarray) {
+function showAllConfirmation(acceptdenyarray) {	
     var a = new Array(acceptdenyarray.length);
     for (var i = 0; i < acceptdenyarray.length; i++) {
-        a[i] = new AcceptDenyObject("calendar", acceptdenyarray[i]);
+        a[i] = new AcceptDenyObject(acceptdenyarray[i].module || "calendar", acceptdenyarray[i]);
     }
     globalconfirm.showConfirmation(a);
 }
