@@ -210,6 +210,19 @@ OXOperationHover.fillParticipants = function(Hover) {
 	Hover.accordion.removeComponent("ParticipantsUsers")
 	var participants=Hover.actualobject.participants;
 	var users=Hover.actualobject.users;
+	var confirmations = Hover.actualobject.confirmations;
+	var confMap = {};
+	if (confirmations) {
+    	for (var i = 0; i < confirmations.length; i++) {
+    	    confMap[confirmations[i].mail] = confirmations[i];
+    	};
+	}
+	
+	var confirmationClasses = {
+	    1: "appointmentACCEPTED",
+	    2: "appointmentDECLINED",
+	    3: "appointmentTENTATIVE"
+	};
 	
 	var tmp_participants=new Array();
 	var checked_confirm=new Object();
@@ -455,10 +468,17 @@ OXOperationHover.fillParticipants = function(Hover) {
 				if(i==0) {
 					tmpn1.getElementsByTagName("td")[0].style.paddingTop="10px";
 					tmpn1.getElementsByTagName("td")[1].style.paddingTop="10px";
+                    tmpn1.getElementsByTagName("td")[2].style.paddingTop="10px";
 				}
 				tmpn1.getElementsByTagName("td")[0].appendChild(newnode("img",null,{src: getFullImgSrc("img/calendar/user_extern.gif")},[]))
 				tmpn1.getElementsByTagName("td")[1].appendChild(document.createTextNode(tmp_external[i].display_name || tmp_external[i].mail || _("Unknown")));
 				tmpn1.getElementsByTagName("td")[1].className="notclickable";
+                if (confirmations) {
+                    var conf = confMap[tmp_external[i].mail];
+				    tmpn1.className = confirmationClasses[conf.status] || "";
+				    tmpn1.getElementsByTagName("td")[2].firstChild.appendChild(
+				        document.createTextNode(conf.message || ""));
+                }
 				accordionnode.getElementsByTagName("tbody")[0].appendChild(tmpn1);
 				Hover.accordion.addComponent("ParticipantsExternal"+i,accordionnode,false);
 				Hover.references.allGroups.push("ParticipantsExternal"+i);		
@@ -864,7 +884,7 @@ OXContactHover.fillGeneral = function(id, folder) {
 }
 
 
-OXContactHover.refillContent = function(id,folder) {
+OXContactHover.refillContent = function(id, folder, callback) {
 	function fillContent(type,value,titletext,clear,show) {
 		if(clear) { removeChildNodes(OXContactHover.references[type]); }
 		if(value) { OXContactHover.references[type].appendChild(value); }
@@ -892,7 +912,9 @@ OXContactHover.refillContent = function(id,folder) {
 	        OXContactHover.slider.getTabById("attachments").setTitle(_("Attachments") + " (0)");
 			OXGroupwareHover.fillAttachments(OXContactHover);
 			
-			OXContactHover.slider.selectTabById("general")
+			OXContactHover.slider.selectTabById("general");
+			
+			if (callback) callback();
 		}
 	});	
 }
