@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan@open-xchange.org>
@@ -295,7 +295,7 @@ function register_Calendar() {
 	/*
 	 * TeamView
 	 */
-	var teamView_show = function(intervalLength, zoom, view) {
+	var teamView_show = function(intervalLength, zoom, view, firstDayOfWeek) {
 	    return function() {
     	    showNode("calendarTeamDay");
             var grid = getCalendarGrid("teamview");
@@ -303,15 +303,16 @@ function register_Calendar() {
 //                grid.zoom = configGetKey("gui.calendar.team.zoom");
 //            }
             grid.zoom = zoom;
+            grid.setFirstDayOfWeek(firstDayOfWeek || 1);
             grid.setGridIntervalLength(intervalLength);
             grid.setParentDOMNode($("teamViewCalendarGrid"));
             grid.setSelectionChangedEvent("SubSelected");
             grid.setTeamMemberChangedEvent("OX_Teammember_Changed");
             grid.setZoomLevelChangedEvent("OX_Zoom_Level_Changed");
-            // is month?
-            if (view == "MONTH") {
+            // align with week month?
+            if (view == "MONTH" || view == "WORKWEEK") {
                 grid.setGridIntervalToWeek(null, intervalLength);
-            }
+            } 
             grid.validateOrUpdate();
             register("OX_Zoom_Level_Changed", storeTeamViewSettings);
             calendarGridHandlers.registerAll();
@@ -321,7 +322,7 @@ function register_Calendar() {
 	var teamView_enter = function() {
 	 // update current team
         var grid = getCalendarGrid("teamview");
-        grid.importTeam();
+        grid.loadDefaultTeam();
         // create menu pulldown (if not exists)
         if (!calendarTeamViewChangeTeamPopup) {
             calendarTeamViewChangeTeamPopup = new PulldownMenu($("menu_calendar_teammember_change"));
@@ -367,6 +368,17 @@ function register_Calendar() {
 	        null
 	        );
 	
+	registerView("calendar/team/workweek",
+			function() {
+	        	teamView_show(configGetKey("gui.calendar.workweek.countdays") || 5, 100,
+	        		"WORKWEEK", configGetKey("gui.calendar.workweek.startday"))();
+			},
+	        teamView_enter,
+	        teamView_leave,
+	        teamView_hide,
+	        null
+	        );
+	
 	registerView("calendar/team/week",
             teamView_show(7, 100, "WEEK"),
             teamView_enter,
@@ -399,47 +411,7 @@ function register_Calendar() {
 		displayNameDayView();
 		loadTeamWeek();
 	}
-	
-	registerView("calendar/team/workweek",
-		function() { 
-			showNode("calendarTeamWeek");
-			if(ctd_participants == null) {
-				$("calendarTeamWeek").style.display=""; 
-				team_initContent();
-			}}, 
-		function() { 
-			// register
-			register("OX_Calendar_Teammember_Add", team_changeTeammembers);
-			register("OX_Calendar_Teammember_Remove", team_removeTeammembers);
-			register("OX_Selected_Member", team_storeSelectedMember);
-			register("OX_Refresh", calendarteamweekrefresh);
-			filldefaultteam();
-			displayNameDayView();
-			loadTeamWeek();
-			if (configGetKey("gui.effects.hover.calendar") && calendarhovers["teamworkweek"]) {
-				calendarhovers["teamworkweek"].enable();
-			}
-		 }, 
-		 function() {
-		 	unloadTeamWeek();
-		 	if (calendarhovers["teamworkweek"]) {
-				calendarhovers["teamworkweek"].disable();
-			}
-		 },
-		function() { 
-			// register
-			unregister("OX_Refresh", calendarteamweekrefresh);
-			unregister("OX_Calendar_Teammember_Add", team_changeTeammembers);
-			unregister("OX_Calendar_Teammember_Remove", team_removeTeammembers);
-			unregister("OX_Selected_Member", team_storeSelectedMember);
-			hideNode("calendarTeamWeek");
-			$("calendarTeamWeek").style.display="none";
-		},
-		function() { 
-			displayNameDayView();
-			loadTeamWeek(); 
-		}
-	);
+
 	registerView("calendar/list",
 		function() { 
 			showNode("calendarList");
@@ -671,7 +643,7 @@ register("Loaded",function() {
     calendarFolderPath = new FolderPath("calendar");
 
     var ids = ["arrowForCWVOptions", "arrowForCWWVOptions",
-        "arrowForCMVOptions", "arrowForTDVOptions", "arrowForTWWVOptions",
+        "arrowForCMVOptions", "arrowForTDVOptions", 
         "arrowForCLVOptions", "arrowForCDetailVOptions"];
     for (var i in ids) {
         var menu = new PulldownMenu($(ids[i]));
@@ -1278,4 +1250,493 @@ function calendar_HeaderUpdate(num) {
 	calendarFolderPath.drawDOMNode(view, activefolder);
 }
 
+/*
+ *	Simple Calendar API
+ */
+
+// calendar namespace
+ox.calendar = { ui: {}, debug: false };
+
+// helper
+ox.calendar.MINUTE = 60 * 1000;
+ox.calendar.HOUR = ox.calendar.MINUTE * 60;
+ox.calendar.DAY = ox.calendar.HOUR * 24;
+ox.calendar.WEEK = ox.calendar.DAY * 7;
+
+ox.calendar.floor = function(timestamp, step) {
+	timestamp = timestamp || 0;
+	step = step || ox.calendar.HOUR;
+	return Math.floor(timestamp / step) * step;
+};
+
+ox.calendar.now = function() {
+	return (new Date()).getTime();
+};
+
+// get
+ox.calendar.get = function(folder_id, id, recurrence_position, callback) {
+
+	// folder_id set?
+	if (!folder_id) {
+		// set default folder
+		folder_id = ox.calendar.getDefaultFolder();
+	}
+	
+	if (typeof folder_id != "undefined" && typeof id != "undefined" && typeof recurrence_position != "undefined") {
+		
+		// ensure default value
+		recurrence_position = recurrence_position || 0;
+		
+		// server request
+		ox.JSON.get(AjaxRoot + "/calendar?action=get&session=" + session + "&id=" + id +
+			"&folder=" + folder_id + "&recurrence_position=" + recurrence_position,
+			// success handler
+			function(response) {
+				// debug?
+				if (ox.calendar.debug) { console.info("ox.calendar.get", clone(response)); }
+				// got a response?
+				if (response && response.data) {
+					// callback
+					if (typeof callback == "function") { callback(response); }
+				}
+			}
+		);
+	} else {
+		// invalid function call
+		console.error(
+			"ox.calendar.get(folder_id : int, id : int, recurrence_position : int, [callback : function]). Invalid parameters.", 
+			folder_id, id, recurrence_position, callback
+		);
+	}
+};
+
+// get multiple
+ox.calendar.getMultiple = function(apps, callback) {
+	// is array?
+	if (apps && apps.length) {
+		// prepare "multiple" request
+		var multiple = [], i = 0, $l = apps.length;
+		for (; i < $l; i++) {
+			var request = {
+                "action": "get",
+                "module": "calendar"
+			};
+			// objects or flat list?
+			if (typeof apps[i] == "number") {
+				app.id = apps[i];
+			}
+			else {
+				var app = apps[i];
+				request.folder = app.folder_id || ox.calendar.getDefaultFolder();
+                request.id = app.id;
+                request.recurrence_position = app.recurrence_position || 0;
+			}
+			multiple.push(request);
+		}
+		// server request
+		ox.JSON.put(AjaxRoot + "/multiple?session=" + session, multiple, function(response) {
+			if (response && typeof callback == "function") {
+				callback(response);
+			}
+		});
+    }
+};
+
+// create appointment
+ox.calendar.create = function(app, callback) {
+	if (app) {
+		// folder not set?
+		if (!app.folder_id) {
+			if (configContainsKey("folder.calendar")) {
+				// set to default folder
+				app.folder_id = configGetKey("folder.calendar");
+			}
+		}
+		// alarm not set?
+		if (!app.alarm) {
+			// default alarm time set?
+			if (configContainsKey("gui.calendar.default_reminder")) {
+				// set to default
+				app.alarm = configGetKey("gui.calendar.default_reminder");
+			}
+		}
+		// mandatory fields defined?
+		if (typeof app.start_date != "undefined" && typeof app.end_date != "undefined" && typeof app.folder_id != "undefined") {
+			// server request
+			ox.JSON.put(AjaxRoot + "/calendar?action=new&session=" + session, app,
+				// success
+				function(response) {
+					if (response && response.data) {
+						// update storage?
+						if (response.data.id) { storageCache.update(); }
+						// callback
+						if (typeof callback == "function") { callback(response); }
+					}
+				}
+			);
+		}
+		else {
+			// invalid function call
+			console.error(
+				"ox.calendar.create(appointment : object, [callback : function]). " + 
+				"Mandatory fields are: folder_id, start_date, end_date.", app
+			);
+		}
+	}
+};
+
+ox.calendar.ui.create = function(app, callback) {
+	// call API
+	ox.calendar.create(app, function(response) {
+		// ignore conflict handler
+		var ignore = function() {
+			// set ignore flag
+			app.ignore_conflicts = true;
+			// try again
+			ox.calendar.create(app, function(response) {
+				// callback
+				if (typeof callback == "function") { callback(response); }
+			});
+		};
+		// conflict?
+		if (response.data.conflicts) {
+			// show conflict dialog
+			ConflictsPopup.open(app, response.data.conflicts, null, null, ignore);
+		}
+		else {
+			// callback
+			if (typeof callback == "function") { callback(response); }
+		}
+	});
+};
+
+// new
+ox.calendar.ui.editNew = function(param) {
+	// mandatory field: folder_id
+	var app = {};
+	// param is number or string?
+	if (typeof param == "number" || typeof param == "string") {
+		// copy folder_id
+		app.folder_id = param;
+	} else if (typeof param == "object") {
+		// copy object
+		app = param;
+	}
+	// folder_id not set?
+	if (typeof app.folder_id == "undefined") {
+		// default folder available?
+		if (configContainsKey("folder.calendar")) {
+			// set to default folder
+			app.folder_id = configGetKey("folder.calendar");
+		}
+	}
+	// folder_id set?
+	if (typeof app.folder_id != "undefined") {
+		// continuation
+		var cont = function() {
+			// start date not set?
+			if (typeof app.start_date == "undefined") {
+				app.start_date = ox.calendar.floor(ox.calendar.now()) + 1; // default: next hour
+			}
+			// end date not set?
+			if (typeof app.end_date == "undefined") {
+				app.end_date = app.start_date + 2 * ox.calendar.HOUR; // default length: two hours
+			}			
+			// open new window
+			newWindow(
+				"newAppointment.html#modul=new&folder_id=" + app.folder_id + 
+				"&start_date=" + app.start_date + "&end_date=" + app.end_date+"", getWindowOptions()
+			);
+		};
+		// has general write privileges?
+		rightshandler.checkRights("calendar", null, app, cont, function() {});
+	}
+	else {
+		// invalid function call
+		console.error(
+			"ox.calendar.ui.editNew(appointment : object | folder_id : int). " + 
+			"Mandatory fields are: folder_id.", app
+		);
+	}
+};
+
+// checks whether the appointment is a recurring appointment
+ox.calendar.isRecurrence = function(app) {
+	return app.recurrence_position > 0 && app.recurrence_id == app.id;
+};
+
+ox.calendar.isSeries = function(app) {
+	return app.recurrence_position == 0 && app.recurrence_type > 0;
+};
+
+ox.calendar.isSingle = function(app) {
+	return app.recurrence_type == 0 || typeof app.recurrence_type == "undefined";
+};
+
+ox.calendar.getDefaultFolder = function() {
+	// default folder available?
+	return configContainsKey("folder.calendar") ? configGetKey("folder.calendar") : null;
+};
+
+// edit
+ox.calendar.ui.edit = function(app) {
+	if (app) {
+		// clear edit lines
+		triggerEvent("OX_Clear_All_Edit_Lines");
+		// dialog handlers
+		var edit = function() {
+			newWindow(
+				"newAppointment.html#modul=edit&view=" + currentCalendarView + "&id=" + app.id + 
+				"&recurrence_position=0&folder_id=" + app.folder_id, getWindowOptions(), app
+			);
+		};
+		var editRecurrence = function() {
+			newWindow(
+					"newAppointment.html#modul=edit&view=" + currentCalendarView + "&id=" + app.id + 
+					"&recurrence_position=" + app.recurrence_position + "&folder_id=" + app.folder_id +
+					"&singleappointment=yes", getWindowOptions(), app
+				);
+		};
+		// write privileges?
+		menuhasRightandLoad([app], "WRITE",
+			// yes
+			function () {
+				// is recurrence?
+				if (ox.calendar.isRecurrence(app)) {
+					// show dialog
+					newConfirm(_("Edit Appointment"),
+						_("Do you want to edit the whole series or a single series appointment? Please note when changing a serial appointment, exceptions to the series are reset."),
+						AlertPopup.SERIESBUTTON, null, null, null, null, edit, editRecurrence
+					);
+				}
+				else {
+					// edit single appointment/series
+					edit();
+				}
+			},
+			// no
+			function() {
+				// trigger event
+				triggerEvent("OX_New_Error", 4, _("You do not have write permission for this object."));
+			}
+		);
+	}
+};
+
+// update
+ox.calendar.update = function(app, callback) {
+	
+	if (app) {
+		
+		var data = app.data, timestamp = app.timestamp;
+		
+		// mandatory fields defined?
+		if (data && typeof timestamp != "undefined" && typeof data.id != "undefined" && 
+			typeof data.folder_id != "undefined" && typeof data.recurrence_position != "undefined") {
+	
+			// adjust request data
+			var requestData = clone(app.data);
+			
+			// clean up first? (exceptions)
+			if (requestData.recurrence_position > 0 && requestData.id != requestData.recurrence_id) {
+				requestData.recurrence_id = requestData.id;
+				requestData.recurrence_position = 0;
+				requestData.recurrence_type = 0;
+			}
+			
+			// is series?
+			if (ox.calendar.isSeries(requestData)) {
+				// remove id & position
+				delete requestData.recurrence_id;
+				delete requestData.recurrence_position;
+			}
+			else {
+				// single appointment or recurrence
+				// remove recurrence information
+				delete requestData.recurrence_id;
+				delete requestData.recurrence_start;
+				delete requestData.recurrence_date_position;
+				delete requestData.days;
+				delete requestData.days_in_month;
+				delete requestData.month;
+				delete requestData.interval;
+				delete requestData.occurrences;
+				delete requestData.until;
+				// update single appointment?
+				if (ox.calendar.isSingle(requestData)) {
+					// remove type
+					delete requestData.recurrence_position;
+					delete requestData.recurrence_type;
+				}
+				else {
+					// make an exception
+					requestData.recurrence_type = 0;
+				}
+			}
+			
+			// debug?
+			if (ox.calendar.debug) { console.info("ox.calendar.update: requestData", requestData); }
+			
+			// server request
+			ox.JSON.put(AjaxRoot + "/calendar?action=update&session=" + session + "&id=" + data.id +
+				"&folder=" + data.folder_id + "&timestamp=" + timestamp,
+				// data
+				requestData,
+				// success handler
+				function(response) {
+					// debug?
+					if (ox.calendar.debug) { console.info("ox.calendar.update", response); }
+					// response?
+					if (response && response.data) {
+						// update timestamp
+						if (response.timestamp) {
+							app.timestamp = response.timestamp;
+						}
+						// callback?
+						if (typeof callback == "function") { callback(response); }
+					}
+				}
+			);
+		}
+		else {
+			// invalid function call
+			console.error(
+				"ox.calendar.update(appointment : object{ data : object, timestamp : int }, [callback : function]). " +
+				"data must include id, folder_id, and recurrence_position.", app
+			);
+		}
+	}
+};
+
+// UI: update
+ox.calendar.ui.update = function(appointment, changes, callback) {
+	
+	// ensure changes
+	changes = changes || {};
+	
+	var ONE_DAY = ox.calendar.DAY;
+	
+	if (typeof appointment != "undefined") {
+		
+		// force notification
+		changes.notification = true;
+		
+		var updateOriginal = function() {
+			// set recurrence position
+			changes.recurrence_position = 0;
+			update();
+		};
+	
+		var updateRecurrence = function() {
+			// ensure recurrence position
+			changes.recurrence_position = appointment.recurrence_position;
+			update();
+		};
+		
+		var dayFloor = function(timestamp) {
+			return Math.floor(timestamp/ONE_DAY)*ONE_DAY;
+		};
+		
+		var update = function() {
+			// get appointment
+			ox.calendar.get(appointment.folder_id, appointment.id, changes.recurrence_position, function(app) {
+				// update series? (check with "appointment", not "changes")
+				if (appointment.recurrence_position > 0) {
+					// start or end changed?
+					if (typeof changes.start_date != "undefined" || typeof changes.end_date != "undefined") {
+						// copy
+						changes.start_date =  changes.start_date || appointment.start_date;
+						changes.end_date =  changes.end_date || appointment.end_date;
+						// adjust start date
+						var shift = changes.start_date - appointment.start_date;
+						app.data.start_date += shift;
+						changes.start_date = app.data.start_date;
+						// adjust end date
+						var shift = changes.end_date - appointment.end_date;
+						app.data.end_date += shift;
+						changes.end_date = app.data.end_date;
+					}
+				}
+				// merge changes
+				for (var key in changes) { app.data[key] = changes[key]; }
+				// debug?
+				if (ox.calendar.debug) { console.info("changes merged", app, changes); }
+				// now update
+				ox.calendar.update(app, function(response) {
+					// conflict?
+					if (response.data.conflicts) {
+						// ignore handler
+						var ignore = function() {
+							// set ignore flag
+							app.data.ignore_conflicts = true;
+							// update again
+							ox.calendar.update(app, function(response) {
+								if (response.data.id) {
+									storageCache.update(triggerEvent("OX_Refresh_Mini_Calendar"));
+								}
+								// callback?
+								if (typeof callback == "function") { callback(response); }
+							});
+						};
+						// show dialog
+						ConflictsPopup.open(app, response.data.conflicts, null, null, ignore);
+					} else {
+						// update storage & mini calendar
+						storageCache.update(triggerEvent("OX_Refresh_Mini_Calendar"));
+						// callback?
+						if (typeof callback == "function") { callback(response); }
+					}
+				});
+			});
+		};
+		
+		var cancel = function() { };
+		
+		// write privileges?
+		menuhasRightandLoad([appointment], "WRITE", function () {
+			// debug?
+			if (ox.calendar.debug) { console.info("write privileges for", clone(appointment)); }
+			// single or series?
+			if (ox.calendar.isRecurrence(appointment)) {
+				// update single appointment within a series
+				// helper
+				var equals = function(timestamp1, timestamp2) {
+					var diff= timestamp1 - timestamp2; 
+					return diff < ONE_DAY && diff > -ONE_DAY && (new Date(timestamp1)).getUTCDate() == (new Date(timestamp2)).getUTCDate();
+				};
+				// debug?
+				if (ox.calendar.debug) { console.info("updating exception/recurrences", appointment); }
+				// part of series?
+				if(!appointment.start_date | !changes.start_date || equals(appointment.start_date, changes.start_date)) {
+					// dialog A
+					newConfirm(
+						_("Edit Appointment"),
+						_("Do you want to edit the whole series or a single series appointment? Please note when changing a serial appointment, exceptions to the series are reset."),
+						AlertPopup.SERIESBUTTON, null, cancel, null, null, updateOriginal, updateRecurrence, cancel
+					);
+				} else {
+					// dialog B
+					newConfirm(
+						_("Edit Appointment"),
+						_("By changing the date of this appointment you are creating an appointment exception to the series. Do you want to continue?"),
+						AlertPopup.CONTINUECANCEL, updateRecurrence, cancel, null, null, updateOriginal, null, cancel, null, updateRecurrence
+					);
+				}
+			} else {
+				// debug?
+				if (ox.calendar.debug) { console.info("updating original", appointment); }
+				// update
+				updateOriginal();
+			}
+		});
+	
+	} else {
+		// invalid function call
+		console.error(
+			"ox.calendar.ui.update(appointment : object, [changes : object], [callback : function]). " +
+			"Invalid parameters.", appointment, changes
+		);
+	}
+};
+
 fileloaded();
\ No newline at end of file
