@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Markus Wagner <markus.wagner@open-xchange.com>
@@ -156,25 +156,19 @@ function initCalenderLiveGridOnLoad() {
                 i18n: true,
                 id: 20,
                 width: "14%",
-                set: function(div,text) {
-                        if(text > 0){
-                            oMainFolderTree.get_folder_path(text, function(path){
-                                var tmp = path.split("/");
-                                if(tmp.length == 1){
-                                    if(div.firstChild)
-                                        div.firstChild.data = tmp[tmp.length-1];
-                                    else
-                                        div.appendChild(document.createTextNode(tmp[tmp.length-1]));
-                                }
-                                else {
-                                    if(div.firstChild)
-                                        div.firstChild.data = tmp[tmp.length-2];
-                                    else
-                                        div.appendChild(document.createTextNode(tmp[tmp.length-2]));
-                                }
-                            });
+                set: function(div,folderId) {
+                        if (folderId > 0) {
+                        	oMainFolderTree.cache.get_folder(folderId, (function(data) {                            	
+                            	function getName(data) {
+                            		return (data && data.oxfolder) ? data.oxfolder.data.title : "";
+                            	}
+                            	if (div.firstChild)
+                            		div.firstChild.data = getName(data);
+                            	else 
+                            		div.appendChild(document.createTextNode(getName(data)));
+                        	}));
                         } else {
-                            if(div.firstChild)
+                            if (div.firstChild)
                                 div.firstChild.data = " ";
                             else
                                 div.appendChild(document.createTextNode(" "));
