@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Suphi Basdemir <suphi.basdemir@open-xchange.com>
@@ -268,6 +268,9 @@ function detailAppointmentOnload(callback)
 						case 'users':
 							objAppDetailParticipants.usersD = fieldsToGet.data[a_d_data];
 							break;
+                        case 'confirmations':
+                            objAppDetailParticipants.confirmationsD = fieldsToGet.data[a_d_data];
+                            break;
 						case 'created_by':
 							internalCache.getUsers([fieldsToGet.data[a_d_data]],	function (arg)
 							{
@@ -311,8 +314,8 @@ function AppDetailParticipants() {
 	this.nPart = 0;
 	this.gridData = new Array();
 	this.gridIndex = 0;
-	this.idForExternal = 1;
 	this.usersD = null;
+	this.confirmationsD = null;
 	this.callback = null;
 }
 
@@ -380,11 +383,10 @@ AppDetailParticipants.prototype = {
 				aPrintDetailApp.push(Print.createContent(_("Participant:"),arg[this.idUserArr[i]].display_name || arg[this.idUserArr[i]].mail));	
 			} else {
 				this.gridData[this.gridIndex] = new Array();
-				this.gridData[this.gridIndex].push(this.idForExternal + "ext");
+				this.gridData[this.gridIndex].push(this.idUserArr[i].mail);
 				this.gridData[this.gridIndex].push("user_extern");
 				this.gridData[this.gridIndex].push(this.idUserArr[i].display_name || this.idUserArr[i].mail);		
 				this.gridIndex++;
-				this.idForExternal ++;
 				aPrintDetailApp.push(Print.createContent(_("Participant:"),this.idUserArr[i].display_name || this.idUserArr[i].mail));
 			}			
 		}
@@ -403,6 +405,10 @@ AppDetailParticipants.prototype = {
 			function() {
 				if(Self.usersD)
 				refAppDetailParticipantTab.users= Self.usersD;
+				if (Self.confirmationsD) {
+				    refAppDetailParticipantTab.confirmations =
+				        Self.confirmationsD;
+				}
 				//refAppDetailParticipantTab.appendToStorage(); Moved to enableGrid
 			},20
 		);
@@ -447,7 +453,7 @@ AppDetailParticipants.prototype = {
 				var start = tmp_grouplength[gr];
 				for(me in arg[gr].members){
 					tmp_members[tmp_grouplength[gr]] = new Array();
-					tmp_members[tmp_grouplength[gr]].push(arg[gr].members[me] + "gm" + arg[gr].id);
+					tmp_members[tmp_grouplength[gr]].push(arg[gr].members[me] + "\0" + arg[gr].id);
 					tmp_members[tmp_grouplength[gr]].push("groupMember");
 					tmp_members[tmp_grouplength[gr]].push(cb[arg[gr].members[me]].display_name);
 					tmp_grouplength[gr]++;
@@ -523,6 +529,7 @@ function transit_a_d_fnSetResourceColumn(arg) {
 
 function ObjAppDetailParticipantTab() {
 	this.users = null;
+	this.confirmations = null;
 	this.list = $("a_d_listParticipants");
 	this.listHeader = $("a_d_listParticipantsHeader");
 	this.myAppPStorage = null;
@@ -614,24 +621,28 @@ ObjAppDetailParticipantTab.prototype = {
 		a_d_participantGrid.getTable(this.list);
 	},
 	
-	appendToStorage : function() {	
-		for(var i = 0; i < objAppDetailParticipants.gridData.length; i++) {
-			for (var t = 0; t < this.users.length; t++) {
-				
-				if(objAppDetailParticipants.gridData[i][0].toString().indexOf("gm") < 0){
-					if(this.users[t].id == objAppDetailParticipants.gridData[i][0]) {
-						objAppDetailParticipants.gridData[i].push(this.users[t].confirmation);
-						objAppDetailParticipants.gridData[i].push(this.users[t].confirmmessage || "");	
-					}
-				} else {
-					if(this.users[t].id == objAppDetailParticipants.gridData[i][0].split("gm")[0]) {
-						objAppDetailParticipants.gridData[i].push(this.users[t].confirmation);
-						objAppDetailParticipants.gridData[i].push(this.users[t].confirmmessage || "");	
-					}
-				}
-			}			
-		}
-	},
+    appendToStorage : function() {
+        var confirmations = {};
+        for (var i = 0; i < this.users.length; i++) {
+            confirmations[this.users[i].id] = {
+                status: this.users[i].confirmation,
+                message: this.users[i].confirmmessage
+            };
+        }
+        for (var i = 0; i < this.confirmations.length; i++) {
+            confirmations[this.confirmations[i].mail] = this.confirmations[i];
+        }
+        for(var i = 0; i < objAppDetailParticipants.gridData.length; i++) {
+            var row = objAppDetailParticipants.gridData[i];
+            var id = String(row[0]);
+            var gm = id.indexOf("\0");
+            if (gm >= 0) id = id.substring(0, gm);
+            if (id in confirmations) {
+    			row.push(confirmations[id].status);
+    			row.push(confirmations[id].message || "");
+            }
+        }
+    },
 	
 	enableGrid : function () {
 		this.appendToStorage();
