@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -27,10 +27,10 @@ function cAnimMiniCalendar(actionFunction, oDOMHeader) {
 		this.header0;
 		this.enable_action = configGetKey("modules.calendar.module");
 		var bDisplayApps = configGetKey("modules.calendar.module");		
-		if(!this.enable_action) {
+		if (!this.enable_action) {
 			actionFunction = function () { 
-				    triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender"); 
-				};
+				triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender"); 
+			};
 		}
 		this.MiniRefer = new cMiniCalendar(oDOMHeader,
 							$("container_mini"), actionFunction,bDisplayApps,
@@ -60,23 +60,20 @@ function cAnimMiniCalendar(actionFunction, oDOMHeader) {
 				oDate.setMonth(oDate.getMonth()-1);
 			} else if (aInf[1] == 2) {
 				oDate.setMonth(oDate.getMonth()-1);
-			}
+			}			
 			oDate.setDate(nDate);
-			function fn() {
-			    
-			    // notify via event
-			    triggerEvent("OX_Mini_Calendar_Date_Picked", oDate.getUTCFullYear(), oDate.getUTCMonth(), oDate.getUTCDate());
-			    
-				if((currentpath2[0] == "calendar") && 
-							(currentpath2[1] == "calendar") &&
-									(currentpath2[2] == "week")) {
-					objWeekCalendarTool.init(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
-					objWeekCalendarTool.setKW();			
-				} else if (currentpath2[1] != "team") {
-					triggerEvent('OX_Switch_View','calendar/calendar/week');		
-					objWeekCalendarTool.init(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
+			function fn() {			    
+			    if (currentpath2[1] != "team") {
+			    	if (currentpath2[2] != "week") {
+			    		triggerEvent('OX_Switch_View','calendar/calendar/week');
+			    	}
+			    	objWeekCalendarTool.init(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
 					objWeekCalendarTool.setKW();
-				}
+					// notify via event
+				    triggerEvent("OX_Mini_Calendar_Date_Picked", oDate.getUTCFullYear(), 
+				    		oDate.getUTCMonth(), oDate.getUTCDate());
+			    }
+			    Self.MiniRefer.setSelectedByDate(oDate.getFullYear(),oDate.getMonth(),oDate.getDate());
 			}
 			// checking if activefolder is type of 'calendar', otherwise jump to standard folder 
             var folder = oMainFolderTree.cache.fast_access[activefolder];
@@ -85,46 +82,44 @@ function cAnimMiniCalendar(actionFunction, oDOMHeader) {
             } else {
             	folder = configGetKey("folder.calendar");
             }
-            setActiveFolder(folder,fn);
+            setActiveFolder(folder,fn);            
 		}
 		function fn_DBLAction(arg) {
 			triggerEvent('OX_Before_Create_Calendar');
+			Self.MiniRefer.setSelectedByDate(Self.selectedYear, Self.selectedMonth, Self.selectedDate);
 		}
-		//don't implement functions for CW clicks and double clicks; simple clicks are disabled in the constructor
-		if(this.enable_action) {
+		// don't implement functions for CW clicks and double clicks; simple clicks are disabled in the constructor
+		if (this.enable_action) {
 			this.MiniRefer.setfnKWAction(fn_KWAction);
 			this.MiniRefer.setfnDBLAction(fn_DBLAction);	
 		} else {
 			this.MiniRefer.setfnKWAction(function() { 
 				    triggerEvent("Feature_Not_Available", "modules/calendar/mini_calender"); 
-				});		
+			});		
 		}
-		this.MiniRefer.setSelectedByDate(this.selectedYear,this.selectedMonth,this.selectedDate);
 }
 cAnimMiniCalendar.prototype = {
-	destroy: function ()
-	{
+	destroy: function() {
 		this.MiniRefer.destroy();
 	},
-	load: function ()
-	{
+	
+	load: function() {
 		this.MiniRefer.load(this.MiniRefer);		
 	},
-	setSelectedByDate: function (year, month, day)
-	{
+	
+	setSelectedByDate: function (year, month, day) {
 		this.MiniRefer.setSelectedByDate(year, month, day);
 	},
-	update: function ()
-	{
+	
+	update: function () {
 		this.MiniRefer.update();
 		this.MiniRefer.setToday();
 	},	
-	setSelected: function (sId)
-	{
+	
+	setSelected: function(sId) {
 		this.MiniRefer.setUnselected();	
 		//find calendar where id is defined
-		if(this.MiniRefer.miniCalendarAssoc[sId])
-		{
+		if (this.MiniRefer.miniCalendarAssoc[sId]) {
 			this.MiniRefer.setSelected(sId);
 			this.selectedDate = this.MiniRefer.selectedDate;
 			this.selectedMonth = this.MiniRefer.selectedMonth;
@@ -134,26 +129,26 @@ cAnimMiniCalendar.prototype = {
 														this.MiniRefer.selectedDate);		
 		}
 	},	
-	checkloaded: function ()
-	{		
+	
+	checkloaded: function() {		
 		return this.MiniRefer.loaded;		
 	},
-	scroll : function (nDirection,cb_fn){
+	
+	scroll: function(nDirection,cb_fn){
 		var Self = this;
 		var nStart = $("minical_slider").scrollLeft;
-		function do_scroll(nStep){
-			if(nDirection > 0)
+		function do_scroll(nStep) {
+			if (nDirection > 0)
 				$("minical_slider").scrollLeft = Math.log(Math.pow(nStep,0.66))*66;
 			else
 				$("minical_slider").scrollLeft = nStart - Math.log(Math.pow(nStep,0.66))*66;
 		}
 		animate((configGetKey("gui.effects.fading") ? 750 : 0), 245, do_scroll,cb_fn);
 	},
-	next: function (num)
-	{
+	
+	next: function(num) {
 		var Self = this;		
-		if(!this.checkloaded() || this.animationInProgress)
-			return;
+		if (!this.checkloaded() || this.animationInProgress) return;
 		var NextDate = new Date();
 		NextDate.setUTCFullYear(this.MiniRefer.currentYear);
 		NextDate.setUTCDate(1);	
@@ -171,7 +166,7 @@ cAnimMiniCalendar.prototype = {
 		this.animationInProgress = true;
 		$("minical_slider").scrollLeft = 0;
 		this.MiniRefer.subcontainer.style.left = "0px";		
-		this.scroll(1,function (){
+		this.scroll(1, function(){
 								$("container_mini").removeChild(Self.MiniRefer.subcontainer);
 								Self.MiniRefer.subcontainer = switchsubContainer;
 								Self.animationInProgress = false;
@@ -179,12 +174,10 @@ cAnimMiniCalendar.prototype = {
 									Self.MiniRefer.update();						
 							});
 	},
-	back: function (num)
-	{
-
+	
+	back: function(num) {
 		var Self = this;		
-		if(!this.checkloaded() || this.animationInProgress)
-			return;
+		if (!this.checkloaded() || this.animationInProgress) return;
 		var NextDate = new Date();
 		NextDate.setUTCFullYear(this.MiniRefer.currentYear);
 		NextDate.setUTCDate(1);	
@@ -210,13 +203,12 @@ cAnimMiniCalendar.prototype = {
 									Self.MiniRefer.update();
 							});
 	},
-	go_to : function (oDate){
+	go_to: function(oDate){
 		this.MiniRefer.go_to(oDate);
 	},
-	today: function (){
-		if (!this.checkloaded() || this.animationInProgress) {
-			return;
-        }
+	
+	today: function() {
+		if (!this.checkloaded() || this.animationInProgress) return;
         
 	    var today = new Date();
 	    activeDay=today.getUTCDate();
@@ -244,8 +236,8 @@ cAnimMiniCalendar.prototype = {
         }
 		this.MiniRefer.go_to(new Date());		
 	},
-	addView: function ()
-	{
+	
+	addView: function() {
 		this.initDate.setMonth(this.initDate.getMonth()+1);		
 		if(!this.header0)	
 		{
@@ -258,19 +250,18 @@ cAnimMiniCalendar.prototype = {
 		}
 		var oHeader = newnode('div',0,{id:'DOMHeaderMini' + this.MiniCalWidgets.length});			
 		var oMiniCalendarNext = new cMiniCalendar(oHeader,
-	 			$("container_mini"),this.actionFunction,true,'mini_subcontainer_'+this.MiniCalWidgets.length,
+	 			$("container_mini"), this.actionFunction,true,'mini_subcontainer_'+this.MiniCalWidgets.length,
 	 													$("header_mini_month"),$("header_mini_year"),this.initDate);
-		if(oMiniCalendarNext.table)	 
+		if (oMiniCalendarNext.table)	 
 			oMiniCalendarNext.subcontainer.insertBefore(oHeader
 															,oMiniCalendarNext.table);
 		else
 			oMiniCalendarNext.subcontainer.appendChild(oHeader);
 		this.MiniCalWidgets.push(oMiniCalendarNext);
 	},
-	removeView: function ()
-	{
-		if(this.header0)
-		{
+	
+	removeView: function() {
+		if(this.header0) {
 			this.MiniCalWidgets[0].subcontainer.removeChild(this.header0);			
 			this.MiniCalWidgets[0].header = this.header;
 			this.header0 = null;
@@ -278,15 +269,14 @@ cAnimMiniCalendar.prototype = {
 		}
 		this.initDate.setMonth(this.initDate.getMonth()-1);
 		var oMonthView = this.MiniCalWidgets.pop();
-		if(oMonthView)
-		{
+		if (oMonthView) {
 			oMonthView.subcontainer.removeChild(oMonthView.header);
 			oMonthView.destroy();
 		}
 	}	
 }
-function cMini3XCalendar(actionFunction,oDOMHeader)
-{
+
+function cMini3XCalendar(actionFunction, oDOMHeader) {
 		this.initDate = new Date();
 		this.actionFunction = actionFunction;
 		this.MiniCalWidgets = new Array();
@@ -535,9 +525,9 @@ cMini3XCalendar.prototype = {
 	}	
 }
 
-function cMiniCalendar(displayPanelContainer,container,actionFunction,
-	bDisplayAppointments,subcontainerid,displayPanelContainerM,displayPanelContainerY,initDate,selectedDate)
-{
+function cMiniCalendar(displayPanelContainer, container, actionFunction,
+			bDisplayAppointments, subcontainerid, displayPanelContainerM,
+				displayPanelContainerY, initDate, selectedDate) {
 	this.enable_action = true;
 	this.aMonthNames = new Array('January','February','March','April','May',
 								'June','July','August','September','October','November','December');
@@ -545,34 +535,23 @@ function cMiniCalendar(displayPanelContainer,container,actionFunction,
 	this.table;
 	this.loaded = false;
 	this.dnd_enabled = false;
-	if(subcontainerid)
-		this.subcontainerid = subcontainerid;
-	else		
-		this.subcontainerid = 'min_subcontainer_default';
+	this.subcontainerid = subcontainerid || "min_subcontainer_default";
 	this.subcontainer = newnode('div');	
-	
 	this.container.appendChild(this.subcontainer);
 	addTMPId(this.subcontainer);
 	this.header = displayPanelContainer;
 	this.header_month = displayPanelContainerM;
 	this.header_year = displayPanelContainerY;	
-	
 	this.actionFN = actionFunction;
 	this.displayAppointments = bDisplayAppointments;
-	
 	var odat = new Date();
-	
 	this.todayDate = odat.getDate();
 	this.todayMonth = odat.getMonth();	
 	this.todayYear = odat.getFullYear();
-
-	if(initDate)
-	{
+	if (initDate) {
 		this.currentMonth = initDate.getUTCMonth();
 		this.currentYear = initDate.getUTCFullYear();
-	}
-	else
-	{
+	} else {
 		this.currentMonth = this.todayMonth;
 		this.currentYear = this.todayYear;
 	}
@@ -585,7 +564,6 @@ function cMiniCalendar(displayPanelContainer,container,actionFunction,
 	this.miniCalendarAssoc = new Object();
 	this.load(this);
 	this.oCalendar;
-	
 	this.oComboMonth;
 	this.oComboYear;	
 	this.fnKWAction = null;
@@ -603,56 +581,43 @@ function cMiniCalendar(displayPanelContainer,container,actionFunction,
 }	
 
 cMiniCalendar.prototype = {
-	setfnDBLAction:function (fn)
-	{
+	setfnDBLAction: function (fn) {
 		this.actionDBLFN = fn;
 	},
-	setfnKWAction:function (fn)
-	{
+	
+	setfnKWAction: function(fn) {
 		this.fnKWAction = fn;
 	},
-	setDate: function (year, month, date){
-	},
-	destroy: function ()
-	{	
+	
+	setDate: function (year, month, date) { },
+	
+	destroy: function() {	
 		this.selectedID = undefined;	
 		this.subcontainer.removeChild(this.table);
 		removeTMPId(this.subcontainer.id+"_table");
-		for(var i=0;$2(this.subcontainer.id+"mc_"+i+"_0");i++) {
-			for(var i2=0;$2(this.subcontainer.id+"mc_"+i+"_"+i2);i2++) {
+		for (var i=0; $2(this.subcontainer.id+"mc_"+i+"_0"); i++) {
+			for (var i2=0; $2(this.subcontainer.id+"mc_"+i+"_"+i2); i2++) {
 				removeTMPId(this.subcontainer.id+"mc_"+i+"_"+i2);
 			}
 		}	
-		for(var i=0;i<54;i++) {
-			if($2("kw_month_"+i)) {
+		for (var i=0; i<54; i++) {
+			if ($2("kw_month_"+i)) {
 				removeTMPId("kw_month_"+i);
 			}
 		}
-		
 		//TODO REMOVE FROM TMPIDS
 		this.loaded = false;
 	},
-	next: function (num)
-	{
+	
+	next: function(num) {
 		if(num == undefined) num = 1;
-		
-		if(!this.loaded)
-			return;
+		if(!this.loaded) return;
 		this.destroy();
 		var oDateLoc = new Date();
 		oDateLoc.setFullYear(this.currentYear);
 		oDateLoc.setDate(1);	
 		oDateLoc.setMonth(this.currentMonth);
-		oDateLoc.setMonth(oDateLoc.getMonth()+num); 	
-		/*
-		var nYearKey = oDateLoc.getFullYear()-this.todayYear;
-		if(!this.oComboYear.setKey(nYearKey))
-		{
-			this.oComboYear.addElement((this.todayYear+nYearKey),nYearKey);
-			this.oComboYear.sort();
-			this.oComboYear.getDomNode();
-			this.oComboYear.setKey(nYearKey);			
-		}*/
+		oDateLoc.setMonth(oDateLoc.getMonth()+num); 
 		this.oComboYear.setDynamicKey(oDateLoc.getFullYear());		
 		this.oComboMonth.setKey(oDateLoc.getMonth());
 
@@ -660,27 +625,16 @@ cMiniCalendar.prototype = {
 		this.currentYear = oDateLoc.getFullYear();		
 		this.load(this);
 	},
-	back: function (num)
-	{
+	
+	back: function(num) {
 		if(num == undefined) num = 1;
-		if(!this.loaded)
-			return;
+		if(!this.loaded) return;
 		this.destroy();
 		var oDateLoc = new Date();
 		oDateLoc.setFullYear(this.currentYear);
 		oDateLoc.setDate(1);	
 		oDateLoc.setMonth(this.currentMonth);
-		oDateLoc.setMonth(oDateLoc.getMonth()-num); 	
-		/*
-		var nYearKey = oDateLoc.getFullYear()-this.todayYear;
-		if(!this.oComboYear.setKey(nYearKey))
-		{
-			this.oComboYear.addElement((this.todayYear+nYearKey),nYearKey);					
-			this.oComboYear.sort();
-			this.oComboYear.getDomNode();
-			this.oComboYear.setKey(nYearKey);				
-		}
-		*/
+		oDateLoc.setMonth(oDateLoc.getMonth()-num); 
 		this.oComboYear.setDynamicKey(oDateLoc.getFullYear());
 		this.oComboMonth.setKey(oDateLoc.getMonth());
 		
@@ -688,58 +642,44 @@ cMiniCalendar.prototype = {
 		this.currentYear = oDateLoc.getFullYear();		
 		this.load(this);
 	},
-	go_to: function (oDateLoc)
-	{
-		if(!this.loaded)
-			return;
-		this.destroy();
 	
+	go_to: function(oDateLoc) {
+		if (!this.loaded) return;
+		this.destroy();
 		this.set_header(oDateLoc);
 		this.currentMonth = oDateLoc.getMonth();
 		this.currentYear = oDateLoc.getFullYear();		
 		this.load(this);
 	},
-	set_header : function (oDateLoc){
+	
+	set_header: function(oDateLoc){
 		unregister('OX_Select_MiniMonth',comboMonthChanged);
-		unregister('OX_Select_MiniYear',comboYearChanged);		
-		//var nYearKey = oDateLoc.getUTCFullYear()-this.todayYear;
+		unregister('OX_Select_MiniYear',comboYearChanged);
 		this.oComboYear.setDynamicKey(oDateLoc.getUTCFullYear());
-/*		if(!this.oComboYear.setDynamicKey(nYearKey))
-		{
-			this.oComboYear.addElement((this.todayYear+nYearKey),nYearKey);
-			this.oComboYear.sort();
-			this.oComboYear.getDomNode();
-			this.oComboYear.setDynamicKey(nYearKey);			
-		}
-		*/
 		this.oComboMonth.setKey(oDateLoc.getUTCMonth());		
 		register('OX_Select_MiniMonth',comboMonthChanged);
 		register('OX_Select_MiniYear',comboYearChanged);		
 	},
-	load: function (obj)
-	{
+	
+	load: function(obj) {
 		this.oCalendar = new cCalendar(this.currentMonth,this.currentYear);
-		if(this.header_month && !this.oComboMonth && !this.oComboYear)
-		{
+		if (this.header_month && !this.oComboMonth && !this.oComboYear) {
 			this.oComboMonth = new ComboBoxSpecial(window, this.header_month.id, '7em', this.todayMonth, 
 																	false, 'OX_Select_MiniMonth', 6,this) ;
 			this.oComboYear = new ComboBoxSpecial(window, this.header_year.id, '3em', 5, 
 																	false, 'OX_Select_MiniYear', 10,this) ;
 			this.oComboYear.optWidth = "4em";
 			this.oComboYear.show_buttons = true;
-			for(var nKeyIndx=-5;nKeyIndx < 5;nKeyIndx++)
-			{
+			for (var nKeyIndx=-5; nKeyIndx < 5; nKeyIndx++){
 				this.oComboYear.addElement((this.todayYear+nKeyIndx),(this.todayYear+nKeyIndx));
 			}
-	
-			for(var nKeyIndx=0;nKeyIndx<this.aMonthNames.length;nKeyIndx++)
-			{
+			for (var nKeyIndx=0;nKeyIndx<this.aMonthNames.length;nKeyIndx++) {
 				this.oComboMonth.addElement(this.aMonthNames[nKeyIndx], nKeyIndx);
 			}
 			this.oComboYear.getDomNode();
 			this.oComboMonth.getDomNode();
-			register('OX_Select_MiniMonth',comboMonthChanged);
-			register('OX_Select_MiniYear',comboYearChanged);			
+			register('OX_Select_MiniMonth', comboMonthChanged);
+			register('OX_Select_MiniYear', comboYearChanged);			
 		}
 		var oFirstDayDate = new Date();
 		var oLastDayDate = new Date();		
@@ -759,37 +699,30 @@ cMiniCalendar.prototype = {
 		var aDay = this.oCalendar.aWeeks[0].aDays[0];
 		var aDay2 = this.oCalendar.aWeeks[(this.oCalendar.aWeeks.length-1)].aDays[6];		
 
-
 		oFirstDayDate.setUTCMonth(this.currentMonth);		
 		oLastDayDate.setUTCMonth(this.currentMonth);			
 
-		if(aDay.nCurrMonth == 0)
+		if (aDay.nCurrMonth == 0) {
 			oFirstDayDate.setUTCMonth(oFirstDayDate.getUTCMonth()-1);
-		if(aDay2.nCurrMonth == 2)
+		}
+		if (aDay2.nCurrMonth == 2) {
 			oLastDayDate.setUTCMonth(oLastDayDate.getUTCMonth()+1);
+		}
 			
 		oFirstDayDate.setUTCDate(aDay.nDate);
 		oLastDayDate.setUTCDate(aDay2.nDate);
-					
+
 		oLastDayDate.setUTCDate(oLastDayDate.getUTCDate()+1);
 		
-		if(!this.displayAppointments)
-		{
+		if (!this.displayAppointments){
 			this.create();
-		}
-		else
-		{
-			function cb_fkt_mc(cbobjCalendar) 
-			{						
-				if(cbobjCalendar && cbobjCalendar.data)
-				{
+		} else {
+			function cb_fkt_mc(cbobjCalendar)  {						
+				if (cbobjCalendar && cbobjCalendar.data) {
 					obj.appointmentList = cbobjCalendar.data;					
-				}
-				else if(cbobjCalendar && cbobjCalendar.error)
-				{
+				} else if(cbobjCalendar && cbobjCalendar.error) {
 					newServerError(cbobjCalendar,4);
-				}
-				else
+				} else
 					triggerEvent('OX_New_Error', 2 ,'Internal Error: No callback parameter in MINICALENDER');
 				obj.create();
 			}
@@ -797,15 +730,14 @@ cMiniCalendar.prototype = {
 		}
 	},
 	
-	getCalObjMC: function(oFirstDayDate,oLastDayDate,callback)
-	{
+	getCalObjMC: function(oFirstDayDate,oLastDayDate,callback) {
 		var start = oFirstDayDate.getTime();
 		var end = oLastDayDate.getTime();		
 		var sAjaxRequest = AjaxRoot + "/calendar?action=has&session=" + session +"&start=" + start + "&end=" + end;
 		calendarMiniJson.get(sAjaxRequest, null, callback);
 	},	
-	update: function ()
-	{
+	
+	update: function() {
 		//TODO
 		var oFirstDayDate = new Date();
 		var oLastDayDate = new Date();		
@@ -818,7 +750,7 @@ cMiniCalendar.prototype = {
 		oLastDayDate.setUTCMinutes(0);		
 		oLastDayDate.setUTCSeconds(0);			
 		oLastDayDate.setUTCDate(1);	
-				
+
 		oFirstDayDate.setUTCFullYear(this.currentYear);
 		oLastDayDate.setUTCFullYear(this.currentYear);		
 
@@ -837,64 +769,57 @@ cMiniCalendar.prototype = {
 		oLastDayDate.setUTCDate(aDay2.nDate);
 		oLastDayDate.setUTCDate(oLastDayDate.getUTCDate()+1);		
 		var Self = this;
-		function fn_refreshCurrentMiniCal(cbobjCalendar)
-		{
-			if(cbobjCalendar && cbobjCalendar.data)
-			{
+		function fn_refreshCurrentMiniCal(cbobjCalendar) {
+			if (cbobjCalendar && cbobjCalendar.data) {
 				Self.appointmentList = cbobjCalendar.data;					
-			}
-			else if(cbobjCalendar && cbobjCalendar.error)
-			{
+			} else if(cbobjCalendar && cbobjCalendar.error) {
 				newServerError(cbobjCalendar);
-			}
-			else
+			} else {
 				triggerEvent('OX_New_Error', 2 ,'Internal Error: No callback parameter in MINICALENDER');
+			}
 			Self.refreshView();			
 		}
-		if(this.displayAppointments)
-			this.getCalObjMC(oFirstDayDate,oLastDayDate,fn_refreshCurrentMiniCal);		
+		if (this.displayAppointments) {
+			this.getCalObjMC(oFirstDayDate,oLastDayDate,fn_refreshCurrentMiniCal);
+		}
 	},	
-	refreshView:function ()
-	{		
+	
+	refreshView: function() {		
 		var nAllDaysCount=0;
 		//loop weeks
-		for(indexWeek=0;indexWeek<this.oCalendar.aWeeks.length;indexWeek++)
-		{
+		for (var indexWeek=0; indexWeek<this.oCalendar.aWeeks.length; indexWeek++){
 				var currentWeek = this.oCalendar.aWeeks[indexWeek];
 				//loop days
-				for(var indexDay=0;indexDay<7;indexDay++)
-				{
-					if(this.displayAppointments)
-					{
-						var bAppExist = this.appointmentList[nAllDaysCount];
+				for (var indexDay=0; indexDay<7; indexDay++) {
+					var bAppExist = false;
+					if (this.displayAppointments) {
+						bAppExist = this.appointmentList[nAllDaysCount];
 					}
-					else
-						var bAppExist = false;
-					var oTD = $2(this.subcontainer.id+'mc_' + indexWeek + '_' + indexDay);
+					var oTD = $2(this.subcontainer.id + 'mc_' + indexWeek + '_' + indexDay);
 					oTD.className = removeClass(oTD.className,"font-style-lable");
-	 				if(bAppExist)
-	 				{
+	 				if(bAppExist) {
 	 					oTD.className += " font-style-lable";		 			
 	 				}
 	 				nAllDaysCount++;
 				}
 				this.loaded = true;
-		}		
+		}	
 	},	
-	create: function()
-	{
+	
+	create: function() {
 		var oCalminiMain = this.subcontainer;
 		oCalminiMain.appendChild(this.getTable());
-
 		this.updateHeaderMini();
 	},
-	getTable : function (oCalObj){
+	
+	getTable: function(oCalObj){
 		var Self = this;
 		var nAllDaysCount = 0;
-		var  oTable = newnode('table',{},{className:"CalMiniMainTable1 background-color-content border-color-content-default",cellPadding: 0, cellSpacing: 0, border: 0});
+		var oTable = newnode("table", {}, { 
+			className: "CalMiniMainTable1 background-color-content border-color-content-default", 
+				cellPadding: 0, cellSpacing: 0, border: 0 });
 		this.table = oTable;
-		var oTableBody = newnode('tbody');	//IE specifical
-		//oTable.id = this.subcontainer.id + "_table";
+		var oTableBody = newnode('tbody');	// IE specific
 		var oTRHead = newnode('tr');
 		var weekDays = [
             { c: "monday"   /*i18n context*/, t: "M"/*i18n*/ },
@@ -925,8 +850,7 @@ cMiniCalendar.prototype = {
 	        };       	
         }
         oTRHead.appendChild(_nTd);
-        
-        for (i = 0; i < weekDays.length; i++) {
+        for (var i=0; i<weekDays.length; i++) {
             var HeadTD = newnode('td', { height:"2em", padding:"0px" }, 0,
                 [addTranslated(weekDays[i].t, weekDays[i].c)]);
 			oTRHead.appendChild(HeadTD);
@@ -935,7 +859,7 @@ cMiniCalendar.prototype = {
 		oTableBody.appendChild(oTRHead);
 		var locCalObj = (oCalObj != undefined) ? oCalObj : this.oCalendar;
 		//loop weeks
-		for (indexWeek=0; indexWeek<locCalObj.aWeeks.length; indexWeek++) {
+		for (var indexWeek=0; indexWeek<locCalObj.aWeeks.length; indexWeek++) {
 				var oTR = newnode('tr', { border:"0" });
 				var currentWeek = locCalObj.aWeeks[indexWeek];
 				var oKWTD = newnode('td', 0, { height:"1.5em", padding:"0px", verticalAlign:"middle",
@@ -943,11 +867,11 @@ cMiniCalendar.prototype = {
 								id:'kw_'+currentWeek.nKW });			
 				var KWTDText = document.createTextNode(currentWeek.nKW);							
 				oKWTD.appendChild(KWTDText);
-				if(!this.enable_action || !this.fnKWAction) {
+				if (!this.enable_action || !this.fnKWAction) {
  					oKWTD.className += " cursorReset";		 			
  				}
-				if(this.fnKWAction != null) {	
-					addDOMEvent(oKWTD,'click',this.fnKWAction);
+				if (this.fnKWAction != null) {	
+					addDOMEvent(oKWTD, "click", this.fnKWAction);
 				}
 				oTR.appendChild(oKWTD);
 				addTMPId(oKWTD);
@@ -987,7 +911,7 @@ cMiniCalendar.prototype = {
  					oDateOthMonth.setMonth(oDateOthMonth.getMonth()+2);	 					
  					nNextMonth = oDateOthMonth.getMonth();
 	 				nNextYear = oDateOthMonth.getFullYear();	 				
-					if((cDay.nCurrMonth == 1 && this.currentYear == this.todayYear
+					if ((cDay.nCurrMonth == 1 && this.currentYear == this.todayYear
 	 														 && this.currentMonth == this.todayMonth
 	 																	 && this.todayDate == cDay.nDate)
 						|| (cDay.nCurrMonth == 0 && nLastYear == this.todayYear
@@ -995,8 +919,8 @@ cMiniCalendar.prototype = {
 	 																	 && this.todayDate == cDay.nDate)
 						|| (cDay.nCurrMonth == 2 && nNextYear == this.todayYear
 	 													&& nNextMonth == this.todayMonth
-	 																	 && this.todayDate == cDay.nDate))	 																	 
-	 				{
+	 																	 && this.todayDate == cDay.nDate)) 
+					{
 		 				oTD.className += " miniCalendarToday todaySelectionBorder";
 		 			
 		 			}
@@ -1014,20 +938,23 @@ cMiniCalendar.prototype = {
  						this.selectedID = sID;
 	 				}	 				
 					oTD.id = sID;
-					if (this.actionDBLFN != null)
+					if (this.actionDBLFN != null) {
+						oTD.onselectstart = function() { return false; };
+						oTD.style.MozUserSelect = "none";
 						oTD.ondblclick = this.actionDBLFN;
+					}
 					oTD.onclick = this.actionFN;		
 					oTR.appendChild(oTD);
 					addTMPId(oTD);
 					function fnOver(node) {
-						return function(e,dragType,draggedObjects,mouseposition,targetNode) {
+						return function(e, dragType, draggedObjects, mouseposition, targetNode) {
 							    minicalenable(e,dragType,draggedObjects,mouseposition,targetNode,node);
                                 var mynode = e.currentTarget || e.srcElement || false;												
 								mynode.className += " dndOver";
 							}
 					}
-					function clearOpenNOdeOver(e,dragType,draggedObjects,mouseposition,OutOpen,dropNode) {
-						if(dropNode) {
+					function clearOpenNOdeOver(e, dragType, draggedObjects, mouseposition, OutOpen, dropNode) {
+						if (dropNode) {
 							dropNode.className = removeClass(dropNode.className,'dndOver');									
 						} else if(e) {
 							var mynode = e.currentTarget || e.srcElement || false;
@@ -1036,7 +963,7 @@ cMiniCalendar.prototype = {
 							}
 						}
 					}
-					if(this.dnd_enabled) {
+					if (this.dnd_enabled) {
 						var tObj = new Object();
 						tObj["mail"] = function (event,dragType,draggedObjects,mouseposition,targetNode,dropNode) {
 										clearOpenNOdeOver(event,dragType,draggedObjects,mouseposition,null,dropNode);
@@ -1044,22 +971,39 @@ cMiniCalendar.prototype = {
 						tObj["contacts"] = function (event,dragType,draggedObjects,mouseposition,targetNode,dropNode) {
 										clearOpenNOdeOver(event,dragType,draggedObjects,mouseposition,null,dropNode);
 										openMailToApp(Self.getDateByID(dropNode.id),draggedObjects.currentObjects,"contacts");}											
-						tObj["calendar"] = function (event,dragType,object,mouseposition,targetNode,dropNode) 										
-						{
-							clearOpenNOdeOver(event,dragType,object,mouseposition,targetNode,dropNode);
-							var subObject = object;
-							if(object && object.currentObjects && object.currentObjects.length>0) {
-									subObject = object.currentObjects[0]; 
-							}
-							var DOMTarget = targetNode;//(evt.currentTarget)?evt.currentTarget:evt.srcElement;			
-							var oDate = Self.getDateByID(dropNode.id);	
-							var start_date = new Date(subObject.start_date);
-							var end_date = new Date(subObject.end_date);	
-							oDate.setUTCHours(start_date.getUTCHours());
-							oDate.setUTCMinutes(start_date.getUTCMinutes());
-							var changes=oDate.getTime()-start_date.getTime();
-							var oDateEnd=new Date(end_date.getTime()+changes);	
-							moveAppToNewStart(subObject,oDate,oDateEnd,function (){Self.update();});
+						tObj["calendar"] = function (event,dragType,draggedObjects,mouseposition,targetNode,dropNode) {
+							clearOpenNOdeOver(event,dragType,draggedObjects,mouseposition,null,dropNode);
+							var collection={};     
+							collection.columns = null;
+				            collection.objects = [];
+				            for (var i in draggedObjects.currentObjects) {
+				            	var myObj = draggedObjects.currentObjects[i];
+				            	collection.objects.push(
+				            			OXCalendarMapping.createKeyFromObject(
+					                      { module: "calendar", 
+					                        folder_id: myObj.folder || myObj.folder_id, 
+					                        id: myObj.id,
+					                        recurrence_position: myObj.recurrence_position || 0 }
+					                  )
+				            	)
+				            }
+				            OXCache.newRequest(null, "calendar", collection, null,
+				                function(daten) {
+				                    for (var j in daten.objects) {
+				                    	
+				                    	var oDate = Self.getDateByID(dropNode.id);
+				                    	var myObj = daten.objects[j];
+				                    	myObj.start_date = new Date(myObj.start_date);
+										myObj.end_date = new Date(myObj.end_date);
+										oDate.setUTCHours(myObj.start_date.getUTCHours());
+										oDate.setUTCMinutes(myObj.start_date.getUTCMinutes());
+										var changes=oDate.getTime()-myObj.start_date.getTime();
+										var oDateEnd=new Date(myObj.end_date.getTime()+changes);
+										moveAppToNewStart(myObj, oDate, oDateEnd, function () { Self.update(); });
+				                    }	
+				                },
+				                true
+				            );
 						}										
 						registerTarget(oTD, tObj,null,null,fnOver(oTD),fnOver(oTD),clearOpenNOdeOver,true);										
 					}
@@ -1069,7 +1013,7 @@ cMiniCalendar.prototype = {
 				this.loaded = true;
 		}
 		//display 6 rows in any case
-		for(indexWeek; indexWeek< 6; indexWeek++) {
+		for(var indexWeek=0; indexWeek< 6; indexWeek++) {
 			var oTR = newnode('tr');
 			var oTD = newnode('td', { height:"1.5em", padding:"0px" }, { colspan:"8", className:"miniCalendarTDNotCurr dateCalendarFontSize font-color-disabled minicalendar6thline"});			
 			oTD.innerHTML = '&#xa0;';
@@ -1080,14 +1024,15 @@ cMiniCalendar.prototype = {
 		addTMPId(oTable);		
 		return oTable;
 	},
-	setSelectedByDate: function (year, month, day) {
+	
+	setSelectedByDate: function(year, month, day) {
 		this.selectedDate = day;
 		this.selectedMonth = month;		
 		this.selectedYear = year;
 		this.selectedTime = Date.UTC(year,month,day);
 		this.setUnselected(this.selectedID);
 		if (this.selectedYear == this.currentYear && this.selectedMonth == this.currentMonth) {
-			for(sId in this.miniCalendarAssoc) {					
+			for (var sId in this.miniCalendarAssoc) {					
 				var nCurrMonthFlag = this.miniCalendarAssoc[sId][1];
 				var nDay = this.miniCalendarAssoc[sId][0];
  				var oDateOthMonth = new Date();
@@ -1101,7 +1046,7 @@ cMiniCalendar.prototype = {
 				oDateOthMonth.setMonth(oDateOthMonth.getMonth()+2);	 					
  					nNextMonth = oDateOthMonth.getMonth();
 	 				nNextYear = oDateOthMonth.getFullYear();	
-				if((nCurrMonthFlag == 1 && nDay == this.selectedDate
+				if ((nCurrMonthFlag == 1 && nDay == this.selectedDate
 												 && this.currentMonth == this.selectedMonth
 												 			&& this.currentYear == this.selectedYear)
 						|| (nCurrMonthFlag == 0 && nLastYear == this.selectedYear
@@ -1126,12 +1071,12 @@ cMiniCalendar.prototype = {
 			this.go_to(oDateLoc);
 		}
 	},
-	setToday : function (){
+	setToday: function() {
 		var todayDate = new Date();
 		this.todayDate = todayDate.getDate();
 		this.todayMonth = todayDate.getMonth();	
 		this.todayYear = todayDate.getFullYear();
-		for(sId in this.miniCalendarAssoc)
+		for(var sId in this.miniCalendarAssoc)
 		{
 			//deselect today selection
 			var currDayDate = $2(sId);
