@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -1023,10 +1023,12 @@ monthView.prototype = {
 			timeDisplayString += " - " + calendarObjects.location;
 		}
 		
+		var owner = getFolderOwner(activefolder);
+		
 		// setting confirmation styles
 		if (calendarObjects.participants.length) {
 			for (var i in calendarObjects.participants) {
-				if (calendarObjects.participants[i].id == config.identifier) {
+				if (calendarObjects.participants[i].id == owner) {
 					switch(calendarObjects.participants[i].confirmation) {
 						case 0:
 							datDIV.style.opacity = ".6";
@@ -1066,6 +1068,7 @@ monthView.prototype = {
 		oInplEdit.input_fontsize = "8pt";
         addDOMEvent(datDIV, "contextmenu", function(e) {
             stopEvent(e);
+            getSelectMonthView(e);
             globalContextMenus.calendar.display(e.clientX, e.clientY,
                                                 calendarSelection);
         });
@@ -1084,9 +1087,9 @@ monthView.prototype = {
 	            getSelectMonthView(e);
 	        }
 	    });     
-	    addDOMEvent(datDIV, "mousedown", function(e) { 
-	        getSelectMonthView(e);
-	    });
+//	    addDOMEvent(datDIV, "mousedown", function(e) { 
+//	        getSelectMonthView(e);
+//	    });
 	    addDOMEvent(datDIV, "dblclick", openAppointmentPopup);
 	
 		datDIV.oxcalobj = "" + calendarObjects.folder_id + "-" + calendarObjects.id 
