@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Markus Wagner <markus.wagner@open-xchange.com>
@@ -1073,13 +1073,12 @@ function fn_afterUpload(errorUpdate) {
 		// and needs to be triggered manually.
 		if (corewindow.currentpath[1] == "detail") {
 			corewindow.reloadAppDetailView(fn_close, clickedItem);							
-		} else if (corewindow.currentpath.join("/") == "calendar/team/day") {
+		} else if (   corewindow.currentpath[0] == "calendar"
+		           && corewindow.currentpath[1] == "team")
+		{
 		    // trigger event
 		    corewindow.triggerEvent("OX_After_New_Appointment");
 			setTimeout(fn_close, 0);
-		} else if (corewindow.currentpath.join("/") == "calendar/team/workweek") {
-			corewindow.loadTeamWeek()
-			setTimeout(fn_close, 0);
 		} else {
 			corewindow.storageCache.update(fn_close);													
 		}
@@ -1264,8 +1263,17 @@ function writeNewAppointment() {
 			starttime = null;
 			endtime = null;
 		
-			ap_object = {};
-	
+			// start with fresh object (single appointment / exception)
+			// or copy all information available (recurrence)
+			if (calenObj.recurrence_position > 0) {
+				// adding the recurrence_position here is mandatory!
+				ap_object = { recurrence_position: calenObj.recurrence_position };
+			} else {
+				// copy all data
+				ap_object = calenObj;
+			}
+			
+			// now overwrite changes
 			if(!ap.newappointment_wholeday.checked)
 				ap_object.start_date = startdate.getTime();
 			else
@@ -1314,11 +1322,14 @@ function writeNewAppointment() {
 					default:
 						break;
 				}
-				if(newAppointment.participants && newAppointment.participants.containsParticipants()) 
-				{
+				
+				if(newAppointment.participants && newAppointment.participants.containsParticipants()) {
 					setBeforeUnload(true);
 					ap_object.participants = newAppointment.participants.getParticipants();
+				} else {
+					ap_object.participants = [];
 				}
+					
 				if(Number(reminderPopup.getKey()) != Number(calenObj.alarm)){
 					updateReminder = true;
 					ap_object.alarm = reminderPopup.getKey();
@@ -1335,36 +1346,32 @@ function writeNewAppointment() {
 				}
 				
                 if (globalseries != null) {
-                    ap_object=globalseries.getParameters(ap_object);                	
+                    ap_object = globalseries.getParameters(ap_object);
                 }
                 
-				if (recurrencePosition > 0) {
-					ap_object.recurrence_position = recurrencePosition;
-				}
-
-				json.put(AjaxRoot + "/calendar?action=update&session=" + session + "&id=" + url["id"] + "&timestamp=" + newappTimestamp + "&folder=" + url["folder_id"], ap_object, null, function(cb){
-					if(cb && cb.data && !cb.data.conflicts){
-						
-						if (newAppointment.attachmentDialog.attach_changed()) 
-						{
-							setBeforeUnload(true);
-							//savePending = true;
-							var obj = new Object();
-							obj['attached'] = cb.data.id;
-							obj['module'] = 1;
-							obj['folder'] = ap_object.folder_id || ap_object.folder; //url["folder_id"];	
-							newAppointment.attachmentDialog.do_post(obj,fn_afterUpload,null,null,cb_error);
+				json.put(AjaxRoot + "/calendar?action=update&session=" + session + "&id=" + url["id"] + "&timestamp=" + newappTimestamp + "&folder=" + url["folder_id"], ap_object, null, 
+					function(cb) {
+						if(cb && cb.data && !cb.data.conflicts) {
+							
+							if (newAppointment.attachmentDialog.attach_changed()) {
+								setBeforeUnload(true);
+								//savePending = true;
+								var obj = new Object();
+								obj['attached'] = cb.data.id;
+								obj['module'] = 1;
+								obj['folder'] = ap_object.folder_id || ap_object.folder; //url["folder_id"];	
+								newAppointment.attachmentDialog.do_post(obj,fn_afterUpload,null,null,cb_error);
+							}
+							else {
+								fn_afterUpload();
+							}
+						} else if (cb && cb.data && cb.data.conflicts) {
+							ConflictsPopup.open(ap_object, cb.data.conflicts, cb_cancelCloseConflict, cb_cancelCloseConflict, cb_ignoreConflict);
 						}
-						else
-						{							
-							fn_afterUpload();							
-
-						}
-					} else if (cb && cb.data && cb.data.conflicts){
-						ConflictsPopup.open(ap_object, cb.data.conflicts, cb_cancelCloseConflict, cb_cancelCloseConflict, cb_ignoreConflict);
 					}
-				});
-			} else if(ap_object.end_date < ap_object.start_date){
+				);
+				
+			} else if(ap_object.end_date < ap_object.start_date) {
 				var tmp = ap_object.start_date - ap_object.end_date;
 				if(tmp > 86400000)
 					triggerEvent("OX_New_Error", 4, _("End date is before start date"));
