@@ -5,7 +5,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2009 Open-Xchange, Inc. Mail: info@open-xchange.com
+ * Copyright (C) 2004-2010 Open-Xchange, Inc. Mail: info@open-xchange.com
  * 
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  * @ignore
@@ -146,6 +146,8 @@ var calendarGridHandlers = {
             grid.setGridInterval(year, month, day);
             grid.clearPartial();
             grid.update();
+            // scroll to working day start time
+            // grid.scroll2Date(new Date(activeYear, activeMonth, activeDay, grid.workdayStart || 0, grid.ONE_HOUR);
         });
     },
     
@@ -163,6 +165,8 @@ var calendarGridHandlers = {
             if (grid.currentTeam != null) {
                 grid.loadTeamByIndex(grid.currentTeam);
             }
+            // update working time
+            grid.loadWorkingDay();
             // refresh
             calendarGridHandlers.refresh();
         });
@@ -264,7 +268,7 @@ function calendarGrid_deleteSelectedAppointments() {
                 // 4. we loop again through the selected appointments
                 for (var i = 0; i < apps.length; i++) {
                     // split up the selection id; format: folder.app_id.app_pos @ user_id:type
-                    var keys = apps[i].selectionId.match(/^\w+\.(\w+\.\w+)\@(\w+)\:(\w+)$/);
+                    var keys = apps[i].selectionId.match(/^\w+\.(\w+\.\w+)\@(\w+)$/);
                     // get the appointment composite key, the participant id, and the type
                     var compId = keys[1];
                     var id = keys[2];
@@ -392,11 +396,14 @@ function CalendarGrid() {
    this.gridIntervalLength = 28;
    this.dayIntervalStart = 0;
    this.dayIntervalEnd = 23;
-   this.workdayStart = configGetKey("gui.calendar.starttime") || 8;
-   this.workdayEnd = configGetKey("gui.calendar.endtime") || 17;
+   
+   this.loadWorkingDay();
+   
+   this.firstDayOfWeek = 1;
    this.ONE_HOUR = 1000 * 60 * 60;
    this.ONE_DAY = this.ONE_HOUR * 24;
    this.ONE_WEEK = this.ONE_DAY * 7;
+   
    // initialize date
    this.setDayInterval();
    this.setGridInterval();
@@ -445,18 +452,12 @@ function CalendarGrid() {
    this.showDetails = true;
 }
 
-/* imports current team of team week (if exists) or loads the default team */
-CalendarGrid.prototype.importTeam = function() {
-    // cooperate with week view - any teams out there?
-    if (hasTeamMembers()) {
-        var Self = this, previousTeam = this.currentTeam;
-        this.loadTeam(getTeamArray(), function() {
-            // reset current team
-            Self.currentTeam = previousTeam;
-        });
-    } else {
-        this.loadDefaultTeam();
-    }
+CalendarGrid.prototype.loadWorkingDay = function() {
+	// read config
+	var start = configGetKey("gui.calendar.starttime");
+	this.workdayStart = start != null ? start : 8;
+	var end = configGetKey("gui.calendar.endtime");
+	this.workdayEnd = end != null ? end : 17;
 }
 
 CalendarGrid.prototype.setDayInterval = function(hourStart, hourEnd) {
@@ -492,13 +493,18 @@ CalendarGrid.prototype.setGridIntervalToWeek = function(timestamp, intervalLengt
     // round down to days
     var t = Math.floor(timestamp/this.ONE_DAY)*this.ONE_DAY;
     // check week day
-    var w = (new Date(t)).getUTCDay() - 1; // sub 1 since it starts with Sunday (=0)
+    var w = (new Date(t)).getUTCDay() - this.firstDayOfWeek; 
+    // sub "firstDay" since it starts with Sunday (=0)
     // subtract days (so that t points at Monday morning) & create date
     var d = new Date(t - w * this.ONE_DAY);
     // set interval (default length = 4 weeks)
     this.setGridInterval(d.getUTCFullYear(), d.getUTCMonth(), d.getUTCDate(), intervalLength || this.gridIntervalLength);
 }
 
+CalendarGrid.prototype.setFirstDayOfWeek = function(day) {
+	this.firstDayOfWeek = day || 1;
+}
+
 CalendarGrid.prototype.setGridIntervalLength = function(intervalLength) {
     // new value?
     if (this.gridIntervalLength != intervalLength) {
@@ -559,7 +565,7 @@ CalendarGrid.prototype.getAppointments = function(callback) {
         // add to request list
         multiple.requests.push(req);
         // appointments already loaded?
-        var rowId = data.id + ":" + data.type;
+        var rowId = data.id; // + ":" + data.type;
         skipRequest = skipRequest && typeof(this.appointments[rowId]) != "undefined";
     }
     
@@ -642,15 +648,22 @@ CalendarGrid.prototype.tidyUpAppointment = function(app) {
 CalendarGrid.prototype.triggerTeamMemberChanged = function() {
     // event defined?
     if (this.teamMemberChangedEvent) {
-        // patch: cooperate with week view
-        importTeam(this.getRowHash());
         // trigger (selected or all)
         triggerEvent(this.teamMemberChangedEvent, this.getSelectedRowsOrAll());
     }
 }
 
 CalendarGrid.prototype.add = function(row) {
-    if (!this.hasRow(row)) {
+	// check for duplicates
+	if (this.hasRow(row)) {
+		// item exists
+		var index = this.rowIndex[row.rowId], test = this.rows[index];
+		// resource overwrites contact?
+		if (test.type == 1 && row.type == 3) {
+			// replace
+			this.replaceAt(row, index);
+		}
+	} else {
         // add to list
         this.rowIndex[row.rowId] = row.index = this.rows.length;
         this.rows.push(row);
@@ -658,9 +671,9 @@ CalendarGrid.prototype.add = function(row) {
         this.autoSort();
         // invalidate current team
         this.currentTeam = null;
+        // trigger event
+        this.triggerTeamMemberChanged();
     }
-    // trigger event
-    this.triggerTeamMemberChanged();
 }
 
 CalendarGrid.prototype.insertAt = function(row, index) {
@@ -674,10 +687,26 @@ CalendarGrid.prototype.insertAt = function(row, index) {
         this.autoSort();
         // invalidate current team
         this.currentTeam = null;
+        // trigger event
+        this.triggerTeamMemberChanged();
     }
-    // trigger event
-    this.triggerTeamMemberChanged();
-}
+};
+
+CalendarGrid.prototype.replaceAt = function(row, index) {
+    if (this.hasRow(row)) {
+        // adjust
+        index = Math.max(0, Math.min(index, this.rows.length));
+        // add to list and update index
+        this.rows.splice(index, 1, row);
+        this.updateRowIndex();
+        // sort rows
+        this.autoSort();
+        // invalidate current team
+        this.currentTeam = null;
+        // trigger event
+        this.triggerTeamMemberChanged();
+    }
+};
 
 CalendarGrid.prototype.hasRow = function(row) {
     return typeof(this.rowIndex[row.rowId]) != "undefined";
@@ -775,7 +804,7 @@ CalendarGrid.prototype.rowSorter = function(a, b) {
 
 CalendarGrid.prototype.loadDefaultTeam = function() {
     // exist in configuration?
-    if (configContainsKey("gui.calendar.teams")) {
+    if (configContainsKey("gui.calendar.teams") && this.currentTeam == null) {
         var teams = configGetKey("gui.calendar.teams");
         // loop teams
         for (var i = 0; i < teams.length; i++) {
@@ -1351,6 +1380,7 @@ CalendarGrid.prototype.changeZoomLevel = function(z) {
         Self.gridHeader.style.fontSize = fs;
         // hide/show hours?
         Self.gridHeader.className = Self.zoom >= CG_HEAD_ZOOM ? "gridHeader zoom1" : "gridHeader zoom0";
+        Self.dataGrid.className = Self.zoom >= CG_HEAD_ZOOM ? "zoom1" : "zoom0";
         // restore correct scroll position
         Self.dataGridContainer.scrollLeft = Self.scrollPositionFix.offsetLeft;
         Self.gridHeader.scrollLeft = Self.scrollPositionFix.offsetLeft;
@@ -1387,9 +1417,19 @@ CalendarGrid.prototype.setZoomLevelChangedEvent = function(eventName) {
     this.zoomLevelChangedEvent = eventName;
 }
 
+CalendarGrid.prototype.getSnapFactor = function() {
+	if (this.zoom < 100) {
+		return 2; // half hour
+	} else if (this.zoom < 300) {
+		return 4; // quarter hour
+	} else {
+		return 12; // 5 minutes
+	}
+}
+
 CalendarGrid.prototype.snapX2grid = function(x, factor) {
     // snap  x position to grid (pixel; half hours / quarter hours)
-    var factor = factor ? factor : (this.zoom <= 400 ? 2 : 4);
+    var factor = factor ? factor : this.getSnapFactor();
     var snapper = 100 * CG_PX2EM * this.zoom / 100 / 24 / factor;
     return Math.round(Math.round(x/snapper)*snapper);
 }
@@ -1406,7 +1446,7 @@ CalendarGrid.prototype.pixel2time = function(x, snap2Grid) {
     // snap to grid?
     if (snap2Grid) {
         // half hour / quarter hour
-        var snapper = this.zoom <= 400 ? this.ONE_HOUR/2 : this.ONE_HOUR/4;
+        var snapper = this.ONE_HOUR / this.getSnapFactor();
         t = Math.round(t/snapper)*snapper;
     }
     return t;
@@ -1479,7 +1519,7 @@ CalendarGrid.prototype.drawPartial = function() {
     for (var i = 0; i < maxCols; i++) {
         for (var h = hourStart; h <= hourStop; h++) {
             var hourClassName = "hour ";
-            hourClassName += h < wdStart || h > wdEnd ? "dark " : "bright ";
+            hourClassName += h <= wdStart || h > wdEnd ? "dark " : "bright ";
             if (i != 0 || h != 0) {
                 hourClassName += h == 0 ? "borderColorMidnight " : h < wdStart || h > wdEnd ? "borderColorDark " : "borderColorBright ";
                 hourClassName += h == 0 ? "borderThick" : "borderThin";
@@ -1490,6 +1530,17 @@ CalendarGrid.prototype.drawPartial = function() {
                 height: ((maxRows+1) * CG_ROW_HEIGHT) + "px"
             }, { className: hourClassName }, [newnode("div", { fontSize: "10px" })]);
             this.dataGrid.appendChild(hour);
+            // extra lines
+            for (var j = 1; j < 12; j++) {
+            	var bStyle = j % 3 == 0 ? " solid" : " dotted";
+            	var bColor = h <= wdStart || h > wdEnd ? " #b1c2e4" : " #ddd"
+            	var helper = newnode("div", {
+            		position: "absolute", borderLeft: "1px" + bStyle + bColor,
+            		left: this.roundEm(i * CG_PX2EM + (h-hourStart) * hourWidth + j * hourWidth/12) + "em",
+                    width: "1px", height: ((maxRows+1) * CG_ROW_HEIGHT) + "px"
+                }, { className: "hour fineLine" }, [newnode("div", { fontSize: "10px" })]);
+            	this.dataGrid.appendChild(helper);
+            }
         }
     }
     // shadows (horizontal; one extra row for new members)
@@ -1762,6 +1813,7 @@ CalendarGrid.prototype.drawPartial = function() {
     this.container.appendChild(header);
     // restore zoom level
     this.gridHeader.className = this.zoom >= CG_HEAD_ZOOM ? "gridHeader zoom1" : "gridHeader zoom0";
+    this.dataGrid.className = this.zoom >= CG_HEAD_ZOOM ? "zoom1" : "zoom0";
     // restore scroll position
     this.dataGridContainer.scrollTop = Self.scrollPositionFix.offsetTop;
     this.dataGridContainer.scrollLeft = Self.scrollPositionFix.offsetLeft;
@@ -1982,6 +2034,7 @@ CalendarGrid.prototype.drawPartial = function() {
     
     // required to get the right class names for different appointment types
     var shownAs2Class = { "1": "reserved", "2": "temporary", "3": "absent", "4": "free" };
+    var shownAs2ZIndex = { "1": 4, "2": 2, "3": 3, "4": 1 };
     
     // get and draw appointments (async.; should be the last thing to do here)
     this.getAppointments(function() { try {
@@ -2060,14 +2113,19 @@ CalendarGrid.prototype.drawPartial = function() {
                 innerDiv.setAttribute("ox_rowId", row.rowId);
                 // now convert microseconds to "em"!
                 var top = (r * CG_ROW_HEIGHT + 5 + (wholeday ? 0 : -3));
-                var left = ((app.start_date - gridStart) * CG_PX2EM / Self.ONE_DAY);
-                var width = (((app.end_date < gridEnd ? app.end_date : gridEnd) - app.start_date) * CG_PX2EM / Self.ONE_DAY);
+                var diff = app.start_date - gridStart, shift = 0;
+                if (diff < 0) {
+                	shift = -diff;
+                	diff = 0;
+                }
+                var left = diff * CG_PX2EM / Self.ONE_DAY;
+                var width = (((app.end_date < gridEnd ? app.end_date : gridEnd) - app.start_date - shift) * CG_PX2EM / Self.ONE_DAY);
                 var height =  (CG_ROW_HEIGHT - 10 - 1 + (wholeday ? 0 : 6));
                 // create outer div
                 var div = newnode("div", {
                     "position": "absolute", "top": top + "px", "left": Self.roundEm(left) + "em",
                     "width": Self.roundEm(width) + "em", "height": height + "px",
-                    zIndex: (wholeday ? 10001 : 10002)
+                    "zIndex": (shownAs2ZIndex[app.shown_as] || 1) * 2 + (wholeday ? 0 : 1)
                 }, null, [innerDiv]);
                 // add to dom
                 Self.appContainer.appendChild(div);
@@ -2105,7 +2163,16 @@ CalendarGrid.prototype.drawPartial = function() {
         
         // scroll to "now"
         if (!Self.manualScroll) {
-            Self.scroll2Date(new Date(), Self.ONE_HOUR);
+        	var d = new Date();
+        	// inside interval?
+        	if (Self.insideGridInterval(d)) {
+        		// scroll to now
+        		Self.scroll2Date(d, Self.ONE_HOUR);
+        	} else {
+        		// scroll to working day start
+        		d = new Date(Self.gridIntervalStart.getTime() + (Self.workdayStart || 0) * Self.ONE_HOUR);
+        		Self.scroll2Date(d, Self.ONE_HOUR);
+        	}
         }
         
         Self.firstRun = false;
@@ -2305,7 +2372,7 @@ function CalendarGridRow(type, id, name, data) {
     this.type = type;
     this.id = id
     // sequenced "id:type" to allow cooperation with team week:
-    this.rowId = id + ":" + type;
+    this.rowId = id; // + ":" + type;
     this.display_name = name || "New member";
     // keep original data (might be useful in future)
     this.data = data || {};
