@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Suphi Basdemir <suphi.basdemir@open-xchange.com>
@@ -527,7 +527,7 @@ WeekCalendarTool.prototype = {
 			}
 		}
 		
-		var participants = this.object[8];
+		var participants = this.object[16];
 		var full_time = this.object[9];
 		var shown_as = this.object[10];
 		var color_label = this.object[11];
@@ -638,9 +638,14 @@ WeekCalendarTool.prototype = {
 		}
 		shownDiv.className += ' showAppointmentShownWeek';
 		
-		var	paramObj = { id: Self.object[0], folder: Self.object[1], 
-		                 folder_id: Self.object[1], recurrence_position: (Self.object[7]) ? Self.object[7] : 0
-		               };
+		var	paramObj = {
+			id: Self.object[0],
+			folder: Self.object[1], 
+		    folder_id: Self.object[1],
+		    recurrence_id: Self.object[14],
+		    recurrence_position: Self.object[7] || 0,
+		    recurrence_type: Self.object[7]
+		};
 
 		function disabled(e) {
 			var iconNode=$2("cww_node_dd");
@@ -685,10 +690,12 @@ WeekCalendarTool.prototype = {
 			textToView += " - " + location;
 		}
 		
+		var owner = getFolderOwner(activefolder);		
+		
 		// setting confirmation styles
 		if (participants.length) {
 			for (var i in participants) {
-				if (participants[i].id == config.identifier) {
+				if (participants[i].id == owner) {
 					switch(participants[i].confirmation) {
 						case 0:
 							datDIV.style.opacity = ".6";
@@ -721,7 +728,7 @@ WeekCalendarTool.prototype = {
         	datDIV.appendChild(divIconTag);
         }
 		
-		if (recurrence_type > 0) {
+		if (nRecPosition > 0 && nRecId == id) {
 			var image=document.createElement("img");
 			image.setAttribute("src",getFullImgSrc("img/calendar/calendar_series.gif"));
 			var seqDiv = newnode('div');
@@ -772,16 +779,12 @@ WeekCalendarTool.prototype = {
         addDOMEvent(datDIV, "contextmenu", 
         	function(e) {            	
         		stopEvent(e);
+        		setSelectionWeekView(selectedAppointmentWeek);
+				selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
             	globalContextMenus.calendar.display(e.clientX, e.clientY, calendarSelection);
         	}
         );
-		addDOMEvent(datDIV, "mousedown", 
-			function(e) {
-				setSelectionWeekView(selectedAppointmentWeek);
-				selectAppointmentWeekView(divAppId, (full_time ? 2 : 1));
-												
-			}
-		);									
+        
 		addDOMEvent(datDIV, "dblclick", 
 			function(e) {
 				setActivatedWeekView(selectedAppointmentWeek, e);
