@@ -6,7 +6,7 @@
  * ,
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -87,7 +87,7 @@ function default_calendar_workweek_create_object(module,folder) {
 	calendar_activedate=null;
 	calendar_wholeday=null;
 }
-function CalendarWorkWeekObject(id,folderid,recurrence_position,recurrence_id,created_by,title,start_date,end_date,note,recurrence_type,participants,full_time,shown_as,color_label,location,private_flag)
+function CalendarWorkWeekObject(id,folderid,recurrence_position,recurrence_id,created_by,title,start_date,end_date,note,recurrence_type,participants,full_time,shown_as,color_label,location,private_flag,interval)
 {
 	this.index;
 	this.selected=false;
@@ -107,6 +107,7 @@ function CalendarWorkWeekObject(id,folderid,recurrence_position,recurrence_id,cr
 	this.shown_as=shown_as;
 	this.color_label=color_label;
 	this.private_flag=private_flag;
+	this.interval=interval;
 	this.divs=new Object();
 }
 CalendarWorkWeekObject.prototype = {
@@ -125,7 +126,7 @@ function MatrixObject(folderid,id,recurrence_id,div_id,startpoint,endpoint) {
 
 var globalinterval = 0;
 var globalintervalcounts=0;
-var calendarwwfields = new Array(200, 201, 202, 203, 209, 221, 401, 402, 102, 400, 101, 220);
+var calendarwwfields = new Array(200, 201, 202, 203, 209, 221, 401, 402, 102, 400, 101, 220, 215);
 var calendarinittemplates=false;
 var firstenter=false;
 var cwwstorage;
@@ -451,7 +452,8 @@ function showCalendarObject(index,object) {
 			}
 		}
 	}
-	var calendarobject = new CalendarWorkWeekObject(object[0],object[1],object[2],object[3],object[4],object[5],object[6],object[7],object[8],object[9],object[10],object[11],object[12],object[13],object[14],object[15]);
+	
+	var calendarobject = new CalendarWorkWeekObject(object[0],object[1],object[2],object[3],object[4],object[5],object[6],object[7],object[8],object[9],object[16],object[11],object[12],object[13],object[14],object[15],object[17]);
 	calendarobject.index=index;
 	allcalendarobjects[""+calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position]=calendarobject;		
 	cwwdrawAppointment(calendarobject);
@@ -596,6 +598,9 @@ function cwwdrawAppointment(calendarobject) {
 	if (edt>cwwactualday.getTime()+(cwwdaysinweek*(oneday))) {
 		edt=new Date(cwwactualday.getTime()+(cwwdaysinweek*oneday)).getTime();
 	}
+	
+	var owner = getFolderOwner(activefolder);
+	
 	var sdttmp=sdt;
 	// IST es ein Ganztagstermin
 	if (calendarobject.full_time){		
@@ -650,11 +655,12 @@ function cwwdrawAppointment(calendarobject) {
 						} 
 					};
 					addDOMEvent(myappointment,"mousedown",function (e) {
-						cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position); 
+						cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position);
+						cancelBubbling(e);
 					});
                     var tds = myappointment.getElementsByTagName("td");
                     var title = tds[1].getElementsByTagName("span")[0];
-					addDOMEvent(tds[1], "click", myfunc1(oInplEdit));		
+					addDOMEvent(tds[1], "mousedown", myfunc1(oInplEdit));		
 					addDOMEvent(myappointment, "click", function(e) {
 							var SelObj = calendarSelection.getID();
 							if (SelObj && SelObj.id == paramObj.id &&
@@ -705,11 +711,11 @@ function cwwdrawAppointment(calendarobject) {
 					if (calendarobject.title) appTitle.push(calendarobject.title);
 					if (calendarobject.location) appTitle.push(calendarobject.location);
 					title.firstChild.data = appTitle.join(" - ") || "";
-					
+										
 					// setting confirmation styles
 					if (calendarobject.participants.length) {
 						for (var i in calendarobject.participants) {
-							if (calendarobject.participants[i].id == config.identifier) {
+							if (calendarobject.participants[i].id == owner) {
 								switch(calendarobject.participants[i].confirmation) {
 									case 0:
 										myappointment.style.opacity = ".6";
@@ -786,7 +792,8 @@ function cwwdrawAppointment(calendarobject) {
 					addTMPId(myappointment,"calendar/calendar/workweek");
 					zaehler3++
 					addDOMEvent(myappointment,"mousedown",function (e) {
-						cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position); 
+						cwwchangeSelected(calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position);
+						cancelBubbling(e);
 					});				
 					var	paramObj = { 
 						id: calendarobject.id, folder_id: calendarobject.folder_id,
@@ -817,7 +824,7 @@ function cwwdrawAppointment(calendarobject) {
 					};
                     var tds = myappointment.getElementsByTagName("td");
                     var title = tds[2].getElementsByTagName("span")[0];
-					addDOMEvent(tds[2], "click", myfunc1(oInplEdit));		
+					addDOMEvent(tds[2], "mousedown", myfunc1(oInplEdit));		
 					addDOMEvent(myappointment, "click", function(e) {
 							var SelObj = calendarSelection.getID();
 							if(SelObj && SelObj.id == paramObj.id &&
@@ -880,8 +887,6 @@ function cwwdrawAppointment(calendarobject) {
 					},null,null,calendardefaultdisabled,defaultdisabledremove);
 					allcalendarobjects[calendarobject.folder_id+"-"+calendarobject.id+"-"+calendarobject.recurrence_position].addDiv(myappointment.id,myappointment);			
 					
-						
-				
 					var appointmentcontainer=cwwdays[sdd].node;
 					//FILL APPOINTMENTS
 						/** Shown As **/
@@ -909,7 +914,7 @@ function cwwdrawAppointment(calendarobject) {
 						// setting confirmation styles
 						if (calendarobject.participants.length) {
 							for (var i in calendarobject.participants) {
-								if (calendarobject.participants[i].id == config.identifier) {
+								if (calendarobject.participants[i].id == owner) {
 									switch(calendarobject.participants[i].confirmation) {
 										case 0:
 											myappointment.style.opacity = ".6";
@@ -934,7 +939,7 @@ function cwwdrawAppointment(calendarobject) {
 							tds[3].getElementsByTagName("img")[0].style.display = "inline";
 						else 
 							tds[3].getElementsByTagName("img")[0].style.display = "none";
-						
+												
 						/** Private or Group **/
 						if(calendarobject.participants && calendarobject.participants.length>1) {
 							tds[3].getElementsByTagName("img")[1].style.display = "inline";
@@ -1828,70 +1833,29 @@ function createPreviewNewAppointmentWW(object) {
 	oInplEdit.on();
 	register("OX_Dummy",dounregister);
 }
-function editAppointment(object,changes, fn_opt) {
-    changes.notification = true;
-	function edit_whole_series(id) {
-		var app_id = id || object.recurrence_id || object.id;
-		json.put(AjaxRoot + "/calendar?action=update&session=" + session + "&id=" + app_id + "&timestamp=" + lastUpdateOfCalendarTimestamp + "&folder=" + object.folder_id, changes, null, 
-		function(cb){
-			if(cb && cb.data && cb.data.conflicts){
-				function cbignore() {
-					changes.ignore_conflicts=true;
-					json.put(AjaxRoot + "/calendar?action=update&session=" + session + "&id=" + app_id + "&timestamp=" + lastUpdateOfCalendarTimestamp + "&folder=" + object.folder_id, changes, null,
-					function(response) {
-						if(response && response.data && response.data.id) {	
-							storageCache.update(triggerEvent("OX_Refresh_Mini_Calendar"));	
-							
-							if(fn_opt)
-								fn_opt();							
-						} 		
-					});
-				}
-				ConflictsPopup.open(object, cb.data.conflicts, null, null,
-                                    cbignore);
-				
-			} else {
-				storageCache.update(triggerEvent("OX_Refresh_Mini_Calendar"));
-				if(fn_opt)
-					fn_opt();
-			}
-		});		
+
+function editAppointment(obj, changes, callback) {
+	// copy important data
+	var app = {
+		id: obj.id,
+		folder_id: obj.folder_id,
+		recurrence_id: obj.recurrence_id,
+		recurrence_position: obj.recurrence_position,
+		recurrence_type: obj.recurrence_type
+	};
+	// start & end data
+	if (typeof obj.start_date != "undefined") { app.start_date = obj.start_date.getTime(); }
+	if (typeof obj.end_date != "undefined") { app.end_date = obj.end_date.getTime(); }
+	// clean up
+	if (app.recurrence_position > 0 && app.id != app.recurrence_id) {
+		app.recurrence_id = app.id;
+		app.recurrence_position = 0;
+		app.recurrence_type = 0;
 	}
-	function edit_single_series() {
-		changes.recurrence_position = object.recurrence_position;
-		edit_whole_series(object.id);
-	}
-	function cancel_edit() {
-		storageCache.update();
-	}
-	if(menuhasRightandLoad([object],"WRITE",
-		function () {
-			if(object.recurrence_position>0 && object.recurrence_id && 
-			   object.recurrence_id == object.id) {
-				function isSameDate(date1,date2) {
-					var diff= date1.getTime() - date2.getTime();
-					if((diff < 1000*60*60*24) && (diff > -(1000*60*60*24))) {
-						if(date1.getUTCDate() == date2.getUTCDate()) {
-							return true;
-						}
-					}
-					return false;
-				}
-				if(!object.start_date | !changes.start_date || isSameDate(object.start_date,new Date(changes.start_date))) {
-					newConfirm(_("Edit Appointment"),_("Do you want to edit the whole series or a single series appointment? Please note when changing a serial appointment, exceptions to the series are reset."),AlertPopup.SERIESBUTTON,null,cancel_edit,null,null,edit_whole_series,edit_single_series,cancel_edit);					
-				} else {
-					newConfirm(_("Edit Appointment"),
-                        _("By changing the date of this appointment you are creating an appointment exception to the series. Do you want to continue?"),
-                        AlertPopup.CONTINUECANCEL, edit_single_series,
-                        cancel_edit, null, null, edit_whole_series, null,
-                        cancel_edit, null, edit_single_series);
-				}
-			} else {
-				edit_whole_series(object.id);
-			}	
-		}
-	)); 
-} 	
+	// update via UI
+	ox.calendar.ui.update(app, changes, callback);
+}
+
 function createAppointment(object) {
 	if (!object.alarm && configContainsKey("gui.calendar.default_reminder")) {
 		object.alarm = configGetKey("gui.calendar.default_reminder");
