@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -421,6 +421,20 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 		saveConfigtoServer("","",myok,myerror,myjson);
 		configuration_changed_outside=false;
 	}
+    if (temporary.folderTabs.viewModified()) {
+        temporary.folderTabs.saveView(configuration_changed_fields.folder ?
+            emptyFunction :
+            function() {
+                oMainFolderTree.cache.updateFolders(
+                    [temporary.folderTabs.folder.id],
+                    function() {
+                        oMainFolderTree.load_view(
+                            oMainFolderTree.cache.folders.root,
+                            oMainFolderTree.tree, true, false);
+                    });
+            });
+        showmessage = false;
+    }
 	if(configuration_changed_fields["folder"] == true) {
 		saveFolder(optParam);
 		configuration_changed_fields["folder"]=false;
@@ -463,18 +477,6 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 		openrequests++;
 		configuration_changed_fields["modules"] = false;
 	}
-    if (temporary.folderTabs.viewModified()) {
-        temporary.folderTabs.saveView(function() {
-            oMainFolderTree.cache.updateFolders(
-                [temporary.folderTabs.folder.id],
-                function() {
-                    oMainFolderTree.load_view(
-                        oMainFolderTree.cache.folders.root,
-                        oMainFolderTree.tree, true, false);
-                }); 
-        });
-        showmessage = false;
-    }
 	if(openrequests==0 && showmessage) {
 		afterRequest();
 	}
