@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Stefan Preuss <stefan.preuss@open-xchange.com>
@@ -112,15 +112,12 @@ register("OX_Configuration_Loaded", function () {
                             // updating folder tree
                             oMainFolderTree.cache.update(null, true, null);
                             // update right checkbox (only)
-                            try {
-                                d = split.get();
-                                d.unified_inbox_enabled = reply.data.unified_inbox_enabled;
-                                split.set(d);
-                                // stop asking if nothing was changes
-                                split.original.unified_inbox_enabled = d.unified_inbox_enabled;
-                                // thx to preuss' "brilliant" idea
-                                mail_accounts.data.data[accountId].unified_inbox_enabled = d.unified_inbox_enabled;
-                            } catch(e) { }
+                            var enabled = reply.data.unified_inbox_enabled;
+                            unifiedCheckbox.set(enabled);
+                            // stop asking if nothing was changes
+                            split.original.unified_inbox_enabled = enabled;
+                            // thx to preuss' "brilliant" idea
+                            mail_accounts.data.data[accountId].unified_inbox_enabled = enabled;
                     });
                 }
             }
@@ -128,6 +125,8 @@ register("OX_Configuration_Loaded", function () {
         return checkbox;
     }
 
+    var unifiedCheckbox;
+    
 	/** Init function **/
 	split.init = function() {
 	    var selection = new Selection();
@@ -145,7 +144,7 @@ register("OX_Configuration_Loaded", function () {
 	        },
 	        // Unified INBOX flag
 	        {
-	            text: _("Use Unified INBOX")/* i18n */,
+	            text: _("Use Unified Mail")/* i18n */,
 	            width: "12em",
 	            clear: emptyFunction,
 	            set: function(div, data) {
@@ -196,7 +195,7 @@ register("OX_Configuration_Loaded", function () {
 	            ox.JSON.put(AjaxRoot + "/account?action=update&session=" +
 	                        session, nData, function(reply) {
 	            				mail_accounts.localUpdate([data.id], function(old) {
-	                                if (!equals(data, old)) return data;
+	                                if (!equals(reply.data, old)) return reply.data;
 	                            });
 	                            ox.Configuration.info(
 	                                _("Your settings have been saved."));
@@ -253,9 +252,9 @@ register("OX_Configuration_Loaded", function () {
 	    /*** menu items ***/
 	    menuarrows[node.id] = {};
 	    
-	    var rulesmenu = MenuNodes.createSmallButtonContext("mail.accounts",
-	        _("Rules"));
-	    MenuNodes.createSmallButton(rulesmenu, "mail.accounts.delete",
+	    var accountsmenu = MenuNodes.createSmallButtonContext("mail.accounts",
+	        _("Accounts"));
+	    MenuNodes.createSmallButton(accountsmenu, "mail.accounts.delete",
 	        _("Delete"), getFullImgSrc("img/menu/delete.gif"),
 	        getFullImgSrc("img/menu/delete_d.gif"), confirmDelete);
 	    function confirmDelete() {
@@ -278,7 +277,7 @@ register("OX_Configuration_Loaded", function () {
 	            oMainFolderTree.cache.update(null, true, null);
 	        }
 	    }
-	    addMenuNode(rulesmenu.node, MenuNodes.FIXED, 31);
+	    addMenuNode(accountsmenu.node, MenuNodes.FIXED, 31);
 	    changeDisplay(node.id, "mail.accounts");
 	    
 	    register("OX_SELECTED_ITEMS_CHANGED", function() {
@@ -322,7 +321,7 @@ register("OX_Configuration_Loaded", function () {
 	    account.addWidget(primary_address, "primary_address");
 	    var personal = new ox.UI.Input(_("Your name"));
 	    account.addWidget(personal, "personal");
-	    var unifiedCheckbox = new ox.UI.CheckBox(_("Use Unified INBOX for this account"));
+	    unifiedCheckbox = new ox.UI.CheckBox(_("Use Unified Mail for this account"));
 	    account.addWidget(unifiedCheckbox, "unified_inbox_enabled");
 	    account.addWidget(new lb());
         split.addWidget(account, {
@@ -524,7 +523,7 @@ register("OX_Configuration_Loaded", function () {
 	    	} else if (mail_server.get() == "") {
 	    		mail_server.formnode.focus();
 	    		return fail(_("Server Name"));
-    		} else if (login.get() == "") {
+    		} else if (login.isEnabled && login.get() == "") {
 	    		login.formnode.focus();
 	    		return fail(_("Login"));
     		} else if (!split["id"] && password.isEnabled && password.get() == "") {
