@@ -5,7 +5,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com
  */
  
@@ -1009,7 +1009,7 @@ ox.UI.Container.prototype = extend(ox.UI.Widget,
             for (var i = 0; i < this.children.length; i++) {
                 if (i in this.names) {
                     var child = this.children[i];
-                    if (child.visible && child.enabled) {
+                    if (child.isVisible && child.isEnabled) {
                         var value = child.get();
                         if (typeof this.names[i] == "string") {
                             data[this.names[i]] = value;
@@ -1150,7 +1150,7 @@ ox.Configuration.View = function(node, title) {
     
     function modified() { return Self.viewModified(); }
     
-    function save() { Self.saveView(); }
+    function save() { if (Self.viewModified()) Self.saveView(); }
     
     function cancel() { Self.cancelView(); }
 };
@@ -1223,7 +1223,7 @@ ox.Configuration.View.prototype = extend(ox.UI.Container,
  * should be a "New" button instead of a "Save" button.
  */
 ox.Configuration.VSplit = function(node, title, size, new_button) {
-    ox.Configuration.View.apply(this, arguments);
+    ox.Configuration.View.call(this, node, title);
 
     /**
      * Current width of the left panel.
@@ -1480,8 +1480,7 @@ ox.Configuration.VSplit.prototype = extend(ox.Configuration.View,
                                     } else {
                                         Self.set(data);
                                         Self.enable();
-                                        Self.id =
-                                            Self.list.storage.makeID(data);
+                                        Self.id = data.id;
                                     }
                                     Self.original = Self.get();
                                 });
@@ -1608,7 +1607,7 @@ ox.Configuration.VSplit.prototype = extend(ox.Configuration.View,
             this.set(data);
             this.enable();
             this.original = this.get();
-            this.id = this.list.storage.makeID(data);
+            this.id = data.id;
         }
         
     });
@@ -1925,7 +1924,7 @@ ox.Configuration.EditableList.prototype = extend(ox.UI.Widget,
                 clear: LiveGrid.makeClear(""),
                 set: LiveGrid.defaultSet
             }], selection);
-            this.grid.emptylivegridtext = this.emptyText;
+            this.grid.emptylivegridtext = this.emptyText();
             this.head = newnode("div");
             this.body = newnode("div",
                 { height: this.height, position: "relative" });
