@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Suphi Basdemir <suphi.basdemir@open-xchange.com>
@@ -143,7 +143,14 @@ registerView("contacts/cards",
 			OXContactHover.accordion.setHover(this);
 			clearCardHoverFields();
 			var splitid=node.oxcontactobj.split("-");
-			OXContactHover.refillContent(splitid[1],splitid[0]);
+			OXContactHover.refillContent(splitid[1], splitid[0], function() {
+				// trigger event
+				var node = OXContactHover.getContent().node || null;
+				var contact = OXContactHover.actualobject || null
+				if (node && contact) {
+					triggerEvent("PAINT_CONTACT", { "view": "hover", "number": 0, "contact": contact, "node": node, "hover": objContactFunctions.refHover });
+				}
+			});
 		}
 		objContactFunctions.refHover.onHide = function (node) {
 			clearCardHoverFields();
@@ -421,6 +428,7 @@ ContactFunctions.prototype = {
             }
         }
 		if(currentpath2[1]=="phonelist") {
+			contactGrid.disablehover=!configGetKey("gui.effects.hover.contacts");
 	        contactGrid.enable(criteria,search,false);
     	} else if(currentpath2[1]=="cards") {
 			var collection={}
@@ -1325,6 +1333,9 @@ function writeCards(currentCardId, columnForDisplyCards, oCurrentContent)
         addDOMEvent(div, "mousedown", mouseDownHandler(currentCardId));
 		if(columnForDisplyCards)
 			columnForDisplyCards.appendChild(div);
+		
+		// trigger event
+		triggerEvent("PAINT_CONTACT", { "view": "card", "number": currentCardId, "contact": oCurrentContent, "node": div });
 			
 	} else {
 		if(columnForDisplyCards)
@@ -1610,97 +1621,34 @@ function showContactDetail(cb_function) {
 		        $('imageContactDetailTd').firstChild.src = getFullImgSrc('img/contacts/dummypicture.gif');
 		    }                                                   
 						
-			var telephone_business1 = daten['telephone_business1'] || "";
-			var telephone_business2 = daten['telephone_business2'] || "";
-			var telephone_company = daten['telephone_company'] || "";
-			var manager_name = daten['manager_name'] || "";
-			var assistant_name = daten['assistant_name'] || "";
-			var telephone_home1 = daten['telephone_home1'] || "";
-			var telephone_home2 = daten['telephone_home2'] || "";
-			var telephone_other = daten['telephone_other'] || "";
-			var fax_business = daten['fax_business'] || "";
-			var fax_home = daten['fax_home'] || "";
-			var fax_other = daten['fax_other'] || "";
-			var cellular_telephone1 = daten['cellular_telephone1'] || "";
-			var cellular_telephone2 = daten['cellular_telephone2'] || "";
-			var telephone_car = daten['telephone_car'] || "";
-			
-			var myCombobox1 = new ComboBox3(window, "combo_telephone_business1", "100%", 0, false, null, 5);
-			myCombobox1.targetDiv = $('abstact_telephone_business1');   
-			myCombobox1.viewValue = true;			
-			myCombobox1.addElement(_("Phone (business):"), telephone_business1);
-			myCombobox1.addElement(_("Phone (business 2):"), telephone_business2);
-			myCombobox1.addElement(_("Phone (private):"), telephone_home1);
-			myCombobox1.addElement(_("Phone (private 2):"), telephone_home2);
-			myCombobox1.addElement(_("Mobile:"), cellular_telephone1);
-			myCombobox1.addElement(_("Mobile (private):"), cellular_telephone2);
-			myCombobox1.addElement(_("Phone (company):"), telephone_company);
-			myCombobox1.addElement(_("Phone (other):"), telephone_other);
-			myCombobox1.addElement(_("Phone (car):"), telephone_car);
-			myCombobox1.addElement(_("Fax (business):"), fax_business);
-			myCombobox1.addElement(_("Fax (private):"), fax_home);
-			myCombobox1.addElement(_("Fax (other):"), fax_other);
-			myCombobox1.addElement(_("Manager:"), manager_name);
-			myCombobox1.addElement(_("Assistant:"), assistant_name);
-			myCombobox1.getDomNode();
-			
-			var myCombobox2 = new ComboBox3(window, "combo_privat_tel", "100%", 2, false, null, 5);
-			myCombobox2.targetDiv = $('abstact_telephone_home1');
-			myCombobox2.viewValue = true;
-			myCombobox2.addElement(_("Phone (business):"), telephone_business1);
-			myCombobox2.addElement(_("Phone (business 2):"), telephone_business2);
-			myCombobox2.addElement(_("Phone (private):"), telephone_home1);
-			myCombobox2.addElement(_("Phone (private 2):"), telephone_home2);
-			myCombobox2.addElement(_("Mobile:"), cellular_telephone1);
-			myCombobox2.addElement(_("Mobile (private):"), cellular_telephone2);
-			myCombobox2.addElement(_("Phone (company):"), telephone_company);
-			myCombobox2.addElement(_("Phone (other):"), telephone_other);
-			myCombobox2.addElement(_("Phone (car):"), telephone_car);
-			myCombobox2.addElement(_("Fax (business):"), fax_business);
-			myCombobox2.addElement(_("Fax (private):"), fax_home);
-			myCombobox2.addElement(_("Fax (other):"), fax_other);
-			myCombobox2.addElement(_("Manager:"), manager_name);
-			myCombobox2.addElement(_("Assistant:"), assistant_name);
-			myCombobox2.getDomNode();
-			
-			var myCombobox3 = new ComboBox3(window, "combo_fax_home", "100%", 10, false, null, 5);
-			myCombobox3.targetDiv = $('abstact_fax_home');
-			myCombobox3.viewValue = true;
-			myCombobox3.addElement(_("Phone (business):"), telephone_business1);
-			myCombobox3.addElement(_("Phone (business 2):"), telephone_business2);
-			myCombobox3.addElement(_("Phone (private):"), telephone_home1);
-			myCombobox3.addElement(_("Phone (private 2):"), telephone_home2);
-			myCombobox3.addElement(_("Mobile:"), cellular_telephone1);
-			myCombobox3.addElement(_("Mobile (private):"), cellular_telephone2);
-			myCombobox3.addElement(_("Phone (company):"), telephone_company);
-			myCombobox3.addElement(_("Phone (other):"), telephone_other);
-			myCombobox3.addElement(_("Phone (car):"), telephone_car);
-			myCombobox3.addElement(_("Fax (business):"), fax_business);
-			myCombobox3.addElement(_("Fax (private):"), fax_home);
-			myCombobox3.addElement(_("Fax (other):"), fax_other);
-			myCombobox3.addElement(_("Manager:"), manager_name);
-			myCombobox3.addElement(_("Assistant:"), assistant_name);
-			myCombobox3.getDomNode();
-			
-			var myCombobox4 = new ComboBox3(window, "combo_mobile_tel", "100%", 4, false, null, 5);
-			myCombobox4.targetDiv = $('cellular_telephone1');
-			myCombobox4.viewValue = true;
-			myCombobox4.addElement(_("Phone (business):"), telephone_business1);
-			myCombobox4.addElement(_("Phone (business 2):"), telephone_business2);
-			myCombobox4.addElement(_("Phone (private):"), telephone_home1);
-			myCombobox4.addElement(_("Phone (private 2):"), telephone_home2);
-			myCombobox4.addElement(_("Mobile:"), cellular_telephone1);
-			myCombobox4.addElement(_("Mobile (private):"), cellular_telephone2);
-			myCombobox4.addElement(_("Phone (company):"), telephone_company);
-			myCombobox4.addElement(_("Phone (other):"), telephone_other);
-			myCombobox4.addElement(_("Phone (car):"), telephone_car);
-			myCombobox4.addElement(_("Fax (business):"), fax_business);
-			myCombobox4.addElement(_("Fax (private):"), fax_home);
-			myCombobox4.addElement(_("Fax (other):"), fax_other);
-			myCombobox4.addElement(_("Manager:"), manager_name);
-			myCombobox4.addElement(_("Assistant:"), assistant_name);            
-			myCombobox4.getDomNode();
-			                    
+            var fields = ["telephone_business1", "telephone_business2",
+                "telephone_home1", "telephone_home2", "cellular_telephone1",
+                "cellular_telephone2", "telephone_company", "telephone_other",
+                "telephone_car", "fax_business", "fax_home", "fax_other",
+                "manager_name", "assistant_name"];
+            var labels = ["Phone (business)"/*i18n*/,
+                "Phone (business 2)"/*i18n*/, "Phone (private)"/*i18n*/,
+                "Phone (private 2)"/*i18n*/, "Mobile"/*i18n*/,
+                "Mobile (private)"/*i18n*/, "Phone (company)"/*i18n*/,
+                "Phone (other)"/*i18n*/, "Phone (car)"/*i18n*/,
+                "Fax (business)"/*i18n*/, "Fax (private)"/*i18n*/,
+                "Fax (other)"/*i18n*/, "Manager"/*i18n*/, "Assistant"/*i18n*/];
+            function fillComboBox(id1, id2, selected) {
+                var combobox = new ComboBox3(window, id1, "100%", selected,
+                                             false, null, 5);
+                combobox.targetDiv = $(id2);
+                combobox.viewValue = true;
+                for (var i = 0; i < fields.length; i++) {
+                    combobox.addElement(_(labels[i]), daten[fields[i]] || "");
+                }
+                combobox.getDomNode();
+            }
+            fillComboBox("combo_telephone_business1",
+                         "abstact_telephone_business1", 0);
+            fillComboBox("combo_privat_tel", "abstact_telephone_home1", 2);
+            fillComboBox("combo_fax_home", "abstact_fax_home", 10);
+            fillComboBox("combo_mobile_tel", "cellular_telephone1", 4);
+            
 			var myCombobox5 = new ComboBox3(window, "combo_email1", "100%", 0, false, "cb_abstact_email1", null);
 			myCombobox5.targetDiv = $('abstact_email1');
 			myCombobox5.viewValue = true;
@@ -1720,33 +1668,33 @@ function showContactDetail(cb_function) {
 			var myCombobox6 = new ComboBox3(window, "combo_instant_messenger1", "100%", 0, false, null, null);
 			myCombobox6.targetDiv = $('instant_messenger1');
 			myCombobox6.viewValue = true;
-			myCombobox6.addElement(_("IM (business):"), daten['instant_messenger1'] || "");
-			myCombobox6.addElement(_("IM (private):"), daten['instant_messenger2'] || "");
+			myCombobox6.addElement(_("IM (business)"), daten['instant_messenger1'] || "");
+			myCombobox6.addElement(_("IM (private)"), daten['instant_messenger2'] || "");
 			myCombobox6.getDomNode();
 			
 			var myCombobox7 = new ComboBox3(window, "combo_telephone_ip", "100%", 0, false, null, null);
 			myCombobox7.targetDiv = $('telephone_ip');
 			myCombobox7.viewValue = true;
-			myCombobox7.addElement(_("IP-Telephone:"), daten['telephone_ip'] || "");
-			myCombobox7.addElement(_("Pager:"), daten['telephone_pager'] || "");
-			myCombobox7.addElement(_("Telex:"), daten['telephone_telex'] || "");
-			myCombobox7.addElement(_("TTY/TDD:"), daten['telephone_ttytdd'] || "");
-			myCombobox7.addElement(_("URL:"), daten['url'] || "");
-			myCombobox7.addElement(_("TAX ID:"), daten['tax_id'] || "");
-			myCombobox7.addElement(_("Commercial Register:"), daten['commercial_register'] || "");
-			myCombobox7.addElement(_("Sales Volume:"), daten['sales_volume'] || "");			
+			myCombobox7.addElement(_("IP phone (private)"), daten['telephone_ip'] || "");
+			myCombobox7.addElement(_("Pager"), daten['telephone_pager'] || "");
+			myCombobox7.addElement(_("Telex"), daten['telephone_telex'] || "");
+			myCombobox7.addElement(_("TTY/TDD"), daten['telephone_ttytdd'] || "");
+			myCombobox7.addElement(_("URL"), daten['url'] || "");
+			myCombobox7.addElement(_("TAX ID"), daten['tax_id'] || "");
+			myCombobox7.addElement(_("Commercial Register"), daten['commercial_register'] || "");
+			myCombobox7.addElement(_("Sales Volume"), daten['sales_volume'] || "");			
 			myCombobox7.getDomNode(); 
 			
 			var myCombobox7_b = new ComboBox3(window, "combo_birthday_status", "100%", 0, false, null, null);
 			myCombobox7_b.targetDiv = $('birthday_status');
 			myCombobox7_b.viewValue = true;
 			if(daten['birthday'] == 0) daten['birthday'] = 1; // 0 -> fix for 01.01.1970
-			myCombobox7_b.addElement(_("Date of birth:"), daten['birthday'] ? formatDate(daten['birthday'], "date") : "");
-			myCombobox7_b.addElement(_("Marital status:"), daten['marital_status'] || "");
-			myCombobox7_b.addElement(_("Spouse's name:"), daten['spouse_name'] || "");
-			myCombobox7_b.addElement(_("Anniversary:"), daten['anniversary'] ? formatDate(daten['anniversary'], "date") : "");
+			myCombobox7_b.addElement(_("Date of birth"), daten['birthday'] ? formatDate(daten['birthday'], "date") : "");
+			myCombobox7_b.addElement(_("Marital status"), daten['marital_status'] || "");
+			myCombobox7_b.addElement(_("Spouse's name"), daten['spouse_name'] || "");
+			myCombobox7_b.addElement(_("Anniversary"), daten['anniversary'] ? formatDate(daten['anniversary'], "date") : "");
 			if(daten['anniversary'] == 0) daten['anniversary'] = 1; // 0 -> fix for 01.01.1970
-			myCombobox7_b.addElement(_("Children:"), daten['number_of_children'] || "");
+			myCombobox7_b.addElement(_("Children"), daten['number_of_children'] || "");
 			myCombobox7_b.getDomNode();
 			myCombobox7_b.setSelectedIndex(0);
 						
@@ -1756,9 +1704,9 @@ function showContactDetail(cb_function) {
 			myCombobox8.targetDiv = $('private_address');
 			myCombobox8.valueIsHTML = true;
 			myCombobox8.viewValue = true;
-			myCombobox8.addElement(_("Address (business):"), myAddresse.addrBusinessDiv);
-			myCombobox8.addElement(_("Address (private):"), myAddresse.addrPrivateDiv);
-			myCombobox8.addElement(_("Address (other):"), myAddresse.addrOtherDiv);
+			myCombobox8.addElement(_("Address (business)"), myAddresse.addrBusinessDiv);
+			myCombobox8.addElement(_("Address (private)"), myAddresse.addrPrivateDiv);
+			myCombobox8.addElement(_("Address (other)"), myAddresse.addrOtherDiv);
 			myCombobox8.getDomNode(); 
 			myCombobox8.setSelectedIndex(0);
 					
@@ -1768,9 +1716,9 @@ function showContactDetail(cb_function) {
 			myCombobox9.targetDiv = $('business_address');			
 			myCombobox9.valueIsHTML = true;
 			myCombobox9.viewValue = true;
-			myCombobox9.addElement(_("Address (business):"), myAddresse.addrBusinessDiv2);
-			myCombobox9.addElement(_("Address (private):"), myAddresse.addrPrivateDiv2);
-			myCombobox9.addElement(_("Address (other):"), myAddresse.addrOtherDiv2);
+			myCombobox9.addElement(_("Address (business)"), myAddresse.addrBusinessDiv2);
+			myCombobox9.addElement(_("Address (private)"), myAddresse.addrPrivateDiv2);
+			myCombobox9.addElement(_("Address (other)"), myAddresse.addrOtherDiv2);
 			myCombobox9.getDomNode(); 
 			myCombobox9.setSelectedIndex(1);
 			
@@ -1786,7 +1734,7 @@ function showContactDetail(cb_function) {
 				    if(i<10) { k = "0" + i; }
 			        else { k = i; }
 			        indexforData = 'userfield'+k;
-			        optinalCombobox[t].addElement(format(_("Optional %d:"),i), daten[indexforData] || "");
+			        optinalCombobox[t].addElement(format(_("Optional %d"),i), daten[indexforData] || "");
 			    }                   
 			    optinalCombobox[t].getDomNode();                        
 			}
@@ -2128,8 +2076,7 @@ function initLiveGridOnLoad()
 		OXContactHover.actualHover=hover;
 		OXContactHover.refillContent(id.id,id.folder_id);					
 	});
-	hover.setSize(OXContactHover.contentobject.node);
-	
+	hover.setSize(OXContactHover.contentobject.node);	
 	
 }
 
