@@ -202,8 +202,8 @@ PreSearch.prototype.presearch = function (searchstring) {
 			case "mail":
 				var column="";
 				var searchcolumn=menumailsearchcontents[mailsearchcontent];
-				if(OXMailObject.stringmapping[searchcolumn]) { 
-					searchcolumn = OXMailObject.stringmapping[searchcolumn];
+				if(OXMailMapping.stringmapping[searchcolumn]) { 
+					searchcolumn = OXMailMapping.stringmapping[searchcolumn];
 					column=""+searchcolumn;
 				} else { 
 					break;
