@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Viktor Pracht <viktor.pracht@open-xchange.com>
@@ -688,23 +688,17 @@ var weekdays = [];
         ")|\'(.+?)\'|(\'\')|([$^\\\\.*+?()[\\]{}|])";
     var pregex = new RegExp(pregexStr, "g");
     
-    var monthRegex = "(" + months.concat(shortMonths).join("|") + ")";
-    
-    var dayRegex = "(" + days.concat(shortDays).join("|") + ")";
-    
-    var monthMap = {};
-    var dayMap = {};
+    var monthRegex;
+    var monthMap;
     function recreateMaps() {
+        var names = months.concat(shortMonths);
+        for (var i = 0; i < names.length; i++) names[i] = escape(_(names[i]));
+        monthRegex = "(" + names.join("|") + ")";
         monthMap = {};
         for (var i = 0; i < months.length; i++) {
             monthMap[_(months[i])] = i;
             monthMap[_(shortMonths[i])] = i;
         }
-        dayMap = {};
-        for (var i = 0; i < days.length; i++) {
-            dayMap[days[i]] = i;
-            dayMap[shortDays[i]] = i;
-        }
         weekdays.length = days.length;
         for (var i = 0; i < days.length; i++) weekdays[i] = _(days[i]);
     }
@@ -740,7 +734,7 @@ var weekdays = [];
     var mrexs = {
         G: prexs.G, y: mnum,
         M: function(n) { return n >= 3 ? monthRegex : mnum(n); },
-        w: mnum, W: mnum, D: mnum, d: mnum, F: mnum, E: prexs.E, a: prexs.e,
+        w: mnum, W: mnum, D: mnum, d: mnum, F: mnum, E: prexs.E, a: prexs.a,
         H: mnum, k: mnum, K: mnum, h: mnum, m: mnum, s: mnum, S: mnum
         // TODO: z and Z
     };
@@ -937,6 +931,8 @@ function round(val) {
  * @param {Number} t The interval in milliseconds
  * @param {Boolean} until Specifies whether the returned text should be in
  * objective case (if true) or in nominative case (if false).
+ * @type String
+ * @return The formatted interval.
  */
 function getInterval(t, until) {
     function minutes(m) {
