@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -55,7 +55,8 @@ function fn_infostore_getDetails(objects, forceUpdate) {
         if (!daten || !daten.objects) {
             enableInfostoreLoadingScreen(false);
             return;
-        }        
+        }
+        getVersions(); // updating versions
         updateInfostoreSplit(daten.objects[0]);
     }, function(daten) {
         if (!daten || !daten.objects) {
@@ -118,9 +119,9 @@ function updateInfostoreSplit(object) {
     if (!object || activemodule != "infostore") return;
     
     // changing the selection jumps back to overview tab
-    if (currentpath2[1] == "split" && currentpath2[2] != "overview") { 
-        triggerEvent("OX_Switch_View", "infostore/split/overview");
-    }
+//    if (currentpath2[2] != "overview") { 
+//        triggerEvent("OX_Switch_View", "infostore/split/overview");
+//    }
     
     activeTaskId = new Array();
     activeTaskId[0]=object;
@@ -765,20 +766,15 @@ function setCurrentVersion() {
     var aVersions = gridVersionsInfoSplit.getSelectedIDs();
     var nVersion = aVersions[0]; //one Selected...
     var nTimeStamp = versionsStorage.timestamp;
-    function cb_set_current(arg)  { getVersions(findVersion); }
+    function cb_set_current(arg)  { 
+    	getVersions(findVersion); 
+    }
     function findVersion() {
         versionsStorage.newIterate([nVersion], emptyFunction, updateCache);
     }
     function updateCache(n, data) {
-        var newData = {
-            filename: data[3],
-            file_mimetype: data[4],
-            file_size: data[5],
-            version: data[0],
-            version_comment: data[8],
-            current_version: true
-        };
-        OXInfoStoreMapping.editObjects([oObjectIdObj], newData);
+    	OXCache.newRequest(null, "infostore", { columns: null,
+            objects: [oObjectIdObj] }, null, emptyFunction, true);
     }
     var newInfoItem = new Object();
     newInfoItem['version'] = parseInt(nVersion);
