@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -414,11 +414,7 @@ function checkLockUnLock(selected) {
 	triggerEvent("OX_Lockable",0,0,0);
 	setTimeout(function() {		
 		var collection = { objects : selected , columns : ["created_by","modified_by","locked_until"] };
-		if (infostoreRequest) {
-	        OXCache.unregister(infostoreRequest.uniqueName);
-	        infostoreRequest = null;
-	    }
-		infostoreRequest=OXCache.newRequest(null,"infostore",collection,null,function(daten) {
+		OXCache.newRequest(null,"infostore",collection,null,function(daten) {
 		     for (var i=0;i<daten.objects.length;i++) {
 		         if (daten.objects[i]["locked_until"] != 0) { 
 	                if (daten.objects[i]["modified_by"] == uid) {
