@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -341,14 +341,14 @@ function callback_update(arg) {
 	if (arg.error) {
 		savePending = false;
 		newServerError(arg);
-	} else {		
-        var oldInfoItem = clone(newInfoItemToWrite);
-        oldInfoItem.id = parseInt(bEditId.id);
-        if (objectVersion !== null) newInfoItemToWrite.version = objectVersion;        
-        corewindow.OXInfoStoreMapping.editObjects([oldInfoItem],newInfoItemToWrite);
+	} else {
+		corewindow.OXCache.newRequest(null, "infostore", { columns: null,
+            objects: [corewindow.OXInfoStoreMapping.createKeyFromObject({
+                module: "infostore", folder_id: bEditId.folder,
+                id: bEditId.id
+            })] }, null, emptyFunction, true);
         corewindow.triggerEvent("OX_Quota_Update");
         setTimeout(corewindow.closeInfoPopUp,50);
-		
 	}
 }
 
