@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Viktor Pracht <viktor.pracht@open-xchange.com>
@@ -24,7 +24,7 @@
  * Each column definition is an object with the following fields:
  * <ul><li>text is used as the column header,</li>
  * <li>i18n specifies whether the text is translated or used directly as
- * innerHTML,</li>
+ * innerHTML (if text is an I18nString, i18n should be false),</li>
  * <li>index is used to extract the value of this column from an item object.
  * If not specified, the entire object is passed to {@link #set}.</li>
  * <li>width specifies the width of the column as a CSS length value,</li>
@@ -271,7 +271,10 @@ LiveGrid.prototype = {
             this.parent.removeChild(this.emptyMessage);
             this.getTable(this.parent);
         }
-        if (this.hoverNode) this.addHover(this.hoverNode, this.hoverCallback);
+        if (this.hoverNode) {
+            this.addHover(this.hoverNode, this.hoverCallback);
+            if (this.hoverSizeNode) this.hover.setSize(this.hoverSizeNode);
+        }
         if (storage) this.enable(storage);
     },
 	
@@ -415,6 +418,10 @@ LiveGrid.prototype = {
 	    this.hoverCallback = callback;
 		this.hover = new Hover(this.heightDiv, hover);
 		var Self = this;
+        this.hover.setSize = function(node) {
+            Self.hoverSizeNode = node;
+            return Hover.prototype.setSize.call(this, node);
+        }
 		this.hover.onShow = function(node) {
 			var i = node.oxRowIndex;
 			if (i !== undefined)
@@ -655,7 +662,7 @@ LiveGrid.prototype = {
 	 */
 	updateStyles: function() {
 		for (var i in this.rows) {
-			var newclass = this.selection.get(i) ? "tr selected" : i%2 ? "tr " : "tr_h ";
+			var newclass = this.selection.get(i) ? "tr selected" : i%2 ? "tr_h " : "tr ";
 			if (focusedElement == this.parent && i == this.focus)
 				newclass += "focused";
 			var tr = this.rows[i].tr;
@@ -680,7 +687,7 @@ LiveGrid.prototype = {
 	insertRow: function(index) {
 		var row = this.rows[index] =
 			this.rowcache.length ? this.rowcache.pop() : this.createRow();
-		row.tr.className = this.selection.get(index) ? "tr selected" : index%2 ? "tr" : "tr_h";
+		row.tr.className = this.selection.get(index) ? "tr selected" : index%2 ? "tr_h" : "tr";
 		row.tr.style.display = "";
 		row.tr.style.top = (index * this.rowHeight) + "px";
 		row.tr.oxRowIndex = index;
@@ -982,7 +989,23 @@ LiveGrid.makeClear = function(text) {
 	};
 };
 
-
+/**
+ * Sort function for use with purely local storages.
+ */
+LiveGrid.localSort = function(id, order) {
+    var a = [];
+    var Self = this;
+    this.storage.newIterate(this.storage.ids, emptyFunction,
+        function(div, data) { a.push(data); }, function() {
+            Self.storage.remove(0, Self.storage.ids.length);
+            a.sort(order == "asc" ? function(a, b) {
+                return a[id] > b[id] ? 1 : a[id] < b[id] ? -1 : 0;
+            } : function(b, a) {
+                return a[id] > b[id] ? 1 : a[id] < b[id] ? -1 : 0;
+            });
+            Self.storage.append(a);
+        });
+};
 
 
 
@@ -1221,7 +1244,10 @@ LiveGrid2.prototype = {
             this.parent.removeChild(this.emptyMessage);
             this.getTable(this.parent);
         }
-        if (this.hoverNode) this.addHover(this.hoverNode, this.hoverCallback);
+        if (this.hoverNode) {
+            this.addHover(this.hoverNode, this.hoverCallback);
+            if (this.hoverSizeNode) this.hover.setSize(this.hoverSizeNode);
+        }
         if (enabled) this.enable(this.collectiondata.criteria,
                                  this.collectiondata.search);
     },
@@ -1254,6 +1280,20 @@ LiveGrid2.prototype = {
 		        this.ids[this.columns[i].sort] = i;		
 			}
 		}
+        this.listColumns = function() {
+        	var colSet = {};
+            for(var i = 0; i < this.columns.length; i++) {
+                var name = this.columns[i].name;
+                for(var j = 0; j < name.length; j++) colSet[name[j]] = true;  
+            }
+            var plainColumns = [], eavColumns = [];
+            for (var i in colSet) {
+                (i.indexOf("/") < 0 ? plainColumns : eavColumns).push(i);
+            }
+            eavColumns.sort();
+            return plainColumns.concat(eavColumns);
+        };
+        
         var colgroup = this.getColGroup();
         colgroup.appendChild(this.ruCorner = newnode("col", {width: "0"}));
         var tbody = newnode("tbody",{verticalAlign : "top"});
@@ -1365,10 +1405,16 @@ LiveGrid2.prototype = {
      * object will be called automatically by the LiveGrid2.
      */
     addHover: function(hover, callback) {
+        this.hoverNode = hover;
+        this.hoverCallback = callback;
 		this.hover = new Hover(this.heightDiv, hover);
         var Self = this;
+        this.hover.setSize = function(node) {
+            Self.hoverSizeNode = node;
+            return Hover.prototype.setSize.call(this, node);
+        }
         this.hover.onShow = function(node) {
-		    var i = node.oxRowIndex;
+            var i = node.oxRowIndex;
             if (i !== undefined)
                 callback(Self.collection.objects[i]);
             else
@@ -1433,15 +1479,9 @@ LiveGrid2.prototype = {
             cb();
         }
 		var selection = (selected) ? this.selection.getSelected() : this.collection.objects;
-		var tmpColumns=[];
-        for(var i=0; i<this.columns.length;i++) {
-            for(var i2=0;i2<this.columns[i].name.length;i2++) {
-                tmpColumns.push(this.columns[i].name[i2]);  
-            }
-        }
         OXCache.newRequest(null,this.module,{
                 objects : selection,
-                columns : tmpColumns
+                columns : this.listColumns()
             },null,function callback(data) {
 				if (!data || !data.objects) {
 					//return;
@@ -1557,22 +1597,24 @@ LiveGrid2.prototype = {
 		var Self=this;
 		this.collectiondata = {
              "criteria" : criteria,
-			 "order" : [{sort : this.sort_id , order : this.sort_order}],
              columns : []
         };
+		if (this.sort_id) {
+            this.collectiondata.order = [{ sort : this.sort_id,
+                                           order : this.sort_order }];
+		}
 		if(search) {
 			this.collectiondata["search"]=search;
 		}
-        if(this.collection) {
-			if(this.uniqueName) {
-			    OXCache.unregister(this.uniqueName);
-                delete this.uniqueName;
-            }
-			if(this.listRequest) {
-                OXCache.unregister(this.listRequest.uniqueName);
-                delete this.listRequest;
-            }   
-		} else {
+		if(this.uniqueName) {
+		    OXCache.unregister(this.uniqueName);
+            delete this.uniqueName;
+        }
+		if(this.listRequest) {
+            OXCache.unregister(this.listRequest.uniqueName);
+            delete this.listRequest;
+        }   
+        if(!this.collection) {
 			for (var i in Self.arrows) {
                 addDOMEvent(Self.outer_headers[i], "click", Self.arrow_events[i]);
 			}
@@ -1612,7 +1654,7 @@ LiveGrid2.prototype = {
             this.collectiondata, {
                 before: function() {
                     oldFocus = Self.focus;
-                    if (!Self.collection) return;
+                    if (!Self.collection || !Self.selection.collection) return;
                     while (Self.selection.get(oldFocus)) oldFocus++;
                     fallbackSelection = Self.collection.objects[oldFocus];
                 },
@@ -1623,7 +1665,7 @@ LiveGrid2.prototype = {
                     if (fallbackSelection) {
                         index = Self.collection.getIndex(fallbackSelection) - 1;
                     }
-                    if (index == undefined) {
+                    if (isNaN(index)) {
                         index = Math.min(oldFocus, Self.rowCount - 1);
                     }
                     if (Self.selection.setCollection(Self.collection, index)) {
@@ -1702,7 +1744,7 @@ LiveGrid2.prototype = {
     	// return if the selection has no collection
     	if (!this.selection.collection) return;
         for (var i in this.rows) {
-            var newclass = this.selection.get(i) ? "tr selected" : i%2 ? "tr " : "tr_h ";
+            var newclass = this.selection.get(i) ? "tr selected" : i%2 ? "tr_h " : "tr ";
             if (focusedElement == this.parent && i == this.focus)
                 newclass += "focused";
             var tr = this.rows[i].tr;
@@ -1727,7 +1769,7 @@ LiveGrid2.prototype = {
     insertRow: function(index) {
         var row = this.rows[index] =
             this.rowcache.length ? this.rowcache.pop() : this.createRow();
-        row.tr.className = this.selection.get(index) ? "tr selected" : index%2 ? "tr" : "tr_h";
+        row.tr.className = this.selection.get(index) ? "tr selected" : index%2 ? "tr_h" : "tr";
         row.tr.style.display = "";
         row.tr.style.top = (index * this.rowHeight) + "px";
         row.tr.oxRowIndex = index;
@@ -1799,16 +1841,6 @@ LiveGrid2.prototype = {
         var ids = [];
         for (var i in this.unfetched) ids.push(this.collection.objects[i]);
         if (ids.length) {        	
-			var tmpColumnsObj=new Object();
-            for(var i=0; i<this.columns.length;i++) {
-                for(var i2=0;i2<this.columns[i].name.length;i2++) {
-                    tmpColumnsObj[this.columns[i].name[i2]] = this.columns[i].name[i2];  
-                }
-            }
-            var tmpColumns=[];
-            for (var i in tmpColumnsObj) {
-            	  tmpColumns.push(i);
-            }
             if(this.listRequest) {
 				OXCache.unregister(this.listRequest.uniqueName);
 				delete this.listRequest;
@@ -1816,7 +1848,7 @@ LiveGrid2.prototype = {
             var collection = this.collection;
 		    this.listRequest=OXCache.newRequest(null,this.module,{
                 objects : ids,
-                columns : tmpColumns
+                columns : this.listColumns()
             },null,function cb(data) {
                 for(var i=0;i<data.objects.length;i++) {
                     var objIndex=collection.map_objects.get(data.objects[i]);
@@ -1825,7 +1857,7 @@ LiveGrid2.prototype = {
                     var cellrow = Self.rows[objIndex-1].cells;
                     for (var i2 in cellrow) {
                         var col = Self.columns[i2];
-                        if(col.name.length==1) {
+                        if(col.name.length==1 && col.name[0].indexOf("/") < 0) {
                           col.set(cellrow[i2], data.objects[i][col.name[0]]);   
                         } else {
                           col.set(cellrow[i2], data.objects[i]);
