@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Stefan Preuss <stefan.preuss@open-xchange.com>
@@ -27,6 +27,7 @@ var mailFetchTimestamp;
 var detailrequest;
 var deleteMailIDs = emptyFunction;
 var switchMailHeaderView, initVsplitSortMenu, loadBlockedImages, oMailFunctions;
+var iMIPAccept;
 
 function infostore_sendLink(obj) {
     function cb_openWindow(arg) {
@@ -397,28 +398,20 @@ function infostore_sendLink(obj) {
 	 * @param grid - {LiveGrid} - the current livegrid 
 	 */
 	function switchGridHeaders(grid) {
-        var map = { from: "to", received_date: "sent_date",
-                    to: "from", sent_date: "received_date" };
-        for (var i in map) if (i in grid.ids) grid.ids[map[i]] = grid.ids[i];
-        
         if (isStdFolder("sent") || isStdFolder("drafts")) {
-            var sHeadline = _("To");
-            var dateHeadline = _("Sent");
+            columnFromTo.text = _("To");
+            columnReceivedSent.text = _("Sent");
             change("from", "to");
             change("received_date", "sent_date");
         } else {
-            var sHeadline = _("From");
-            var dateHeadline = _("Received");
+            columnFromTo.text = _("From");
+            columnReceivedSent.text = _("Received");
             change("to", "from");
             change("sent_date", "received_date");
         }
         
-        function change(oldCol, newCol) {
+        function change(oldCol, newCol, column) {
             if (sort_id == oldCol) sort_id = newCol;
-            if(oldCol in grid.ids) { 
-                grid.columns[grid.ids[oldCol]].sort = newCol; 
-                grid.columns[grid.ids[oldCol]].name[0] = newCol;
-            }
             for (var i = 0; i < grid.columns.length; i++) {
                 var name = grid.columns[i].name;
                 for (var j = 0; j < name.length; j++) {
@@ -427,17 +420,14 @@ function infostore_sendLink(obj) {
             }
         }
 		
-		if (grid && grid.headers) {
-			if (view !== vsplit) {
-				grid.headers[3].firstChild.data = sHeadline;
-				grid.headers[3].title = sHeadline;				
-				grid.headers[5].firstChild.data = dateHeadline;
-				grid.headers[5].title = dateHeadline;
-			} else {
-				if (grid.headers[3] && grid.headers[3].firstChild && grid.headers[3].firstChild.firstChild)
-					grid.headers[3].firstChild.firstChild.data = sHeadline;
-			}
-		}
+        if (view === vsplit && grid.headers[3]
+                            && grid.headers[3].firstChild
+                            && grid.headers[3].firstChild.firstChild)
+        {
+            grid.headers[3].firstChild.firstChild.data = columnFromTo.text;
+        }
+
+        grid.recreate();
 
         // update folder name and unread count information for grid header
         //setMailHeaderLabel();
@@ -460,51 +450,60 @@ function infostore_sendLink(obj) {
 		var attachments = [];
 		// if only one object has been selected, print the detail message, otherwise the list
 		if (view.grid.selection.getSelected().length == 1) {
-			var omsg = OXCache.cachedObjects.get(view.grid.selection.getSelected()[0]);
-	        var cnn = "", attachmentParam=null;
-	        if(omsg["attachments_plain"] && !configGetKey("mail.inlineattachments")) { 
-	            attachmentParam = omsg["attachments_plain"]; 
-	        } else if (omsg["attachments_html"] && configGetKey("mail.inlineattachments")) { 
-	            attachmentParam = omsg["attachments_html"]; 
-	        } else if (omsg["attachments_html_noimage"] && configGetKey("mail.inlineattachments")) { 
-	            attachmentParam = omsg["attachments_html_noimage"];
-	        }
-            for (idfield in attachmentParam) {
-                var conArr = attachmentParam[idfield];
-                var ct = conArr["content_type"] ? conArr["content_type"].toLowerCase() : "application/unknown";
-                var con = conArr["content"];
-                if (ct.search(/text\//) != -1 && con != null) {
-                    if (ct.search(/text\/plain/) != -1) {
-                        var tmpcnn=(configGetKey("mail.emoticons") ? replaceSmilies(con) : con);
-                        tmpcnn=replaceLeadingSpaces(tmpcnn);
-                        cnn += "<div style=\"font-family: monospace; line-height: 1.5em;\">" + tmpcnn + "</div>";
-                    } else { 
-                        cnn += "<div>" + con + "</div>";
-                    }           
-                } else if(conArr["filename"]) {
-                	attachments.push(conArr);
-                }        
-            }
-            
-            if (omsg["nested_msgs"] && omsg["nested_msgs"].length) {
-	            for (var nMessage = 0; nMessage < omsg["nested_msgs"].length; nMessage++) {
-	            	var nmg = omsg["nested_msgs"][nMessage];
-	            	attachments.push({ filename: nmg.filename || nmg.subject, content_type: "message/rfc822", size: nmg.size });	            
-	            }
-            }
-	        var tmsg = new Object();
-	        //tmsg["whole_message"] = omsg;
-	        tmsg["message_text"] = cnn;
-	        tmsg["message_attachments"] = attachments;
-	        if (omsg.from) tmsg["from"] = getAdressString(omsg.from, false);
-	        if (omsg.to)  tmsg["to"] = getAdressString(omsg.to, false);
-	        if (omsg.cc)  tmsg["cc"] = getAdressString(omsg.cc, false);
-	        if (omsg.bcc) tmsg["bcc"] = getAdressString(omsg.bcc, false);
-	        tmsg["date"] = omsg.sent_date;
-	        tmsg["subject"] = omsg.subject;
-	        tmsg["priority"] = omsg.priority;
-	        tmsg["color-label"] = omsg.color_label;			
-	        mail_printDetailMail(tmsg);
+			var collection={};
+			collection.objects=[view.grid.selection.getSelected()[0]];
+			// need to get mail out of cache, specially if we don't have all data (like on the list view)
+			var omsg = OXCache.newRequest(null, "mail", collection,	null,
+				function(data) {
+				    if (data.objects.length) {
+				    	var omsg = data.objects[0];
+				    	var cnn = "", attachmentParam=null;
+				        if(omsg["attachments_plain"] && !configGetKey("mail.inlineattachments")) { 
+				            attachmentParam = omsg["attachments_plain"]; 
+				        } else if (omsg["attachments_html"] && configGetKey("mail.inlineattachments")) { 
+				            attachmentParam = omsg["attachments_html"]; 
+				        } else if (omsg["attachments_html_noimage"] && configGetKey("mail.inlineattachments")) { 
+				            attachmentParam = omsg["attachments_html_noimage"];
+				        }
+			            for (idfield in attachmentParam) {
+			                var conArr = attachmentParam[idfield];
+			                var ct = conArr["content_type"] ? conArr["content_type"].toLowerCase() : "application/unknown";
+			                var con = conArr["content"];
+			                if (ct.search(/text\//) != -1 && con != null) {
+			                    if (ct.search(/text\/plain/) != -1) {
+			                        var tmpcnn=(configGetKey("mail.emoticons") ? replaceSmilies(con) : con);
+			                        tmpcnn=replaceLeadingSpaces(tmpcnn);
+			                        cnn += "<div style=\"font-family: monospace; line-height: 1.5em;\">" + tmpcnn + "</div>";
+			                    } else { 
+			                        cnn += "<div>" + con + "</div>";
+			                    }           
+			                } else if(conArr["filename"]) {
+			                	attachments.push(conArr);
+			                }        
+			            }
+			            
+			            if (omsg["nested_msgs"] && omsg["nested_msgs"].length) {
+				            for (var nMessage = 0; nMessage < omsg["nested_msgs"].length; nMessage++) {
+				            	var nmg = omsg["nested_msgs"][nMessage];
+				            	attachments.push({ filename: nmg.filename || nmg.subject, content_type: "message/rfc822", size: nmg.size });	            
+				            }
+			            }
+				        var tmsg = new Object();
+				        //tmsg["whole_message"] = omsg;
+				        tmsg["message_text"] = cnn;
+				        tmsg["message_attachments"] = attachments;
+				        if (omsg.from) tmsg["from"] = getAdressString(omsg.from, false);
+				        if (omsg.to)  tmsg["to"] = getAdressString(omsg.to, false);
+				        if (omsg.cc)  tmsg["cc"] = getAdressString(omsg.cc, false);
+				        if (omsg.bcc) tmsg["bcc"] = getAdressString(omsg.bcc, false);
+				        tmsg["date"] = omsg.sent_date;
+				        tmsg["subject"] = omsg.subject;
+				        tmsg["priority"] = omsg.priority;
+				        tmsg["color-label"] = omsg.color_label;			
+				        mail_printDetailMail(tmsg);
+			        }			
+				}
+			); 
 		} else { 
 			globalprint.printLiveGrid(view.grid);
 		}		
@@ -711,7 +710,8 @@ function infostore_sendLink(obj) {
         triggerEvent("OX_Selected_Draft", isStdFolder("drafts"));
 	}
     
-    temporary.lists.mail = temporary.MakeList({
+    var columnFromTo, columnReceivedSent;
+	temporary.lists.mail = temporary.MakeList({
         addIcon: function(icon) {
             var col = this.columns[0];
             if (icon.name) {
@@ -809,7 +809,7 @@ function infostore_sendLink(obj) {
                         div.firstChild.src = getFullImgSrc("img/mail/read.gif");
                     }
                 }
-            }, {
+            }, columnFromTo = {
                 text: "From",  /*i18n*/
                 name : ["from","level","flags"],
                 sort : "from",
@@ -832,7 +832,7 @@ function infostore_sendLink(obj) {
                     if (div.firstChild)
                         div.firstChild.data = padding + addressString;
                     else
-                        div.appendChild(newtext(padding + addressStrin));
+                        div.appendChild(newtext(padding + addressString));
                     //deleted                                                   
                     div.style.textDecoration =  content["flags"] & 2 ? "line-through" : "none";
                     //unread
@@ -854,7 +854,7 @@ function infostore_sendLink(obj) {
                     div.style.textDecoration =  content["flags"] & 2 ? "line-through" : "none";
                 },
                 clear: clear
-            }, {                
+            }, columnReceivedSent = {                
                 text: "Received", /*i18n*/
                 i18n: true,
                 sortable: true,
@@ -953,7 +953,8 @@ function infostore_sendLink(obj) {
             var tds = div.getElementsByTagName("td");
             var sent = isStdFolder("sent") || isStdFolder("drafts");
             function setIcon(index, path, width) {
-                var fullpath = getFullImgSrc(path);
+                var fullpath = path.charAt(0) == "/" ? path.substring(1)
+                                                     : getFullImgSrc(path);
                 if (tds[index].firstChild.src != fullpath) {
                     tds[index].firstChild.src = fullpath;
                     if (width) tds[index].style.width = width;
@@ -1076,24 +1077,35 @@ function infostore_sendLink(obj) {
 	/**
 	 * Open a new message window
 	 */
-	function newMail(action) {				
+	function newMail(action) {
+		var folder = encodeURIComponent(activefolder), id="";		
+		if (message && trimStr(action).length != 0) {
+			 folder = encodeURIComponent(message.folder_id);
+			 id = encodeURIComponent(message.id);
+		}
+		var acc = corewindow.getMailAccountIdByFolder(folder);
+		// in case of unified we have to use the folder out of the id instead
+		if (id.match(/^default/)) {
+			acc = corewindow.getMailAccountIdByFolder(id);
+		}
 		var newMail = newWindow("newMail.html#"
-		    + "folder="	+ (message ? encodeURIComponent(message.folder_id) : "") 
-			+ "&id=" + (message ? encodeURIComponent(message.id) : "")
+		    + "folder="	+ folder
+			+ "&id=" + id
+			+ "&account=" + acc
 			+ "&action=" + action,
 			getWindowOptions(null, screen.availHeight-25));
 		newMail.focus();
 		
 		// fill object for multiple selected messages, eg. on a forward
-        if (newMail && mailSelection.getSelected().length > 1) {
-	        var selected = mailSelection.getSelected();
-	        var fObj = [];
-	        for (var i in selected) {           
-	            fObj.push({"folder": selected[i].folder_id, "id": selected[i].id });
-	        }
-            newMail.multiForward = fObj;
-        }
-        return newMail;
+		if (newMail && mailSelection.getSelected().length > 1) {
+		    var selected = mailSelection.getSelected();
+		    var fObj = [];
+		    for (var i in selected) {           
+		        fObj.push({"folder": selected[i].folder_id, "id": selected[i].id });
+		    }
+		    newMail.multiForward = fObj;
+		}
+		return newMail;
 	}
 
 	/**
@@ -1445,6 +1457,148 @@ function infostore_sendLink(obj) {
 			$("mail."+view.name+".detail.header.image_protection").style.display="none";
 		}
 		
+		// iMIP
+		var methodRE = /;\s*method\s*=\s*(?:([-!#-'*+.0-9A-Z^-~]*)|"([\cA-\b\cK\cL\cN-\x1f!#-[\]-\x7f]*)")/i;
+		var iMIPRequest = $("mail." + view.name + ".detail.header.imip");
+        var iMIPReply = $("mail." + view.name + ".detail.header.imipreply");
+        var iMIPAttachments = message.attachments_html ||
+            message.attachments_html_noimage || message.attachments_plain;
+		checkiMIP: {
+            if (iMIPAttachments) {
+        		for (var i = 0; i < iMIPAttachments.length; i++) {
+        		    var match = methodRE.exec(iMIPAttachments[i].content_type);
+        		    if (match) switch ((match[1] || match[2]).toLowerCase()) {
+        		        case "request":
+        		            iMIPAccept = makeAccept(message.folder_id,
+        		                                    message.id,
+        		                                    iMIPAttachments[i].id);
+                            $("mail." + view.name + ".detail.header.imip.note").value = "";
+                            iMIPRequest.style.display = "";
+                            iMIPReply.style.display = "none";
+                            break checkiMIP;
+        		        case "reply":
+        		            iMIPUpdate = makeUpdate(message.folder_id,
+                                                    message.id,
+                                                    iMIPAttachments[i].id);
+                            iMIPRequest.style.display = "none";
+        		            iMIPReply.style.display = "";
+        		            break checkiMIP;
+        		    }
+        		}
+            }
+    		iMIPRequest.style.display = "none";
+            iMIPReply.style.display = "none";
+		}
+        function makeAccept(folder, id, cid) {
+            return function(status) {
+                ox.JSON.put(
+                    AjaxRoot + "/conversion?action=convert&session=" + session,
+                    {
+                        datasource: {
+                            identifier: "com.openexchange.mail.ical",
+                            args: [
+                                { "com.openexchange.mail.conversion.fullname":
+                                    folder },
+                                { "com.openexchange.mail.conversion.mailid":
+                                    id },
+                                { "com.openexchange.mail.conversion.sequenceid":
+                                    cid }
+                            ]
+                        },
+                        datahandler: {
+                            identifier: "com.openexchange.ical",
+                            args: [
+                                   { "com.openexchange.groupware.calendar.folder":
+                                       configGetKey("folder.calendar") },
+                                   { "com.openexchange.groupware.task.folder":
+                                       configGetKey("folder.tasks") },
+                                   { "com.openexchange.groupware.calendar.confirmstatus":
+                                       status },
+                                   { "com.openexchange.groupware.calendar.confirmmessage":
+                                       $("mail." + view.name + ".detail.header.imip.note").value },
+                            ]
+                        }
+                    },
+                    function() {
+                        ox.Configuration.info(_("Confirmation sent."));
+                    }
+                );
+            };
+        }
+        function makeUpdate(folder, id, cid) {
+            return function() {
+                ox.JSON.put(
+                    AjaxRoot + "/conversion?action=convert&session=" + session,
+                    {
+                        datasource: {
+                            identifier: "com.openexchange.mail.ical",
+                            args: [
+                                { "com.openexchange.mail.conversion.fullname":
+                                    folder },
+                                { "com.openexchange.mail.conversion.mailid":
+                                    id },
+                                { "com.openexchange.mail.conversion.sequenceid":
+                                    cid }
+                            ]
+                        },
+                        datahandler: {
+                            identifier: "com.openexchange.ical.json",
+                            args: [
+                                { "com.openexchange.groupware.calendar.searchobject":
+                                    true }
+                            ]
+                        }
+                    },
+                    function(reply) {
+                        var map = {};
+                        for (var i = 0; i < reply.data.length; i++) {
+                            var o = { folder: reply.data[i].folder_id,
+                                      id: reply.data[i].id };
+                            if (!o.id || !o.folder) {
+                                ox.Configuration.error(format(
+                                    //#. %s is the title of the appointment
+                                    _("Appointment '%s' not found."),
+                                    reply.data[i].title));
+                                return;
+                            }
+                            map[o.folder_id + "\0" + o.id] = o;
+                        }
+                        var objects = [];
+                        for (var i in map) objects.push(map[i]);
+                        ox.JSON.put(AjaxRoot +
+                            "/calendar?action=list&columns=1&recurrence_master=true&session=" +
+                            session, objects, handleList);
+                        function handleList(reply2) {
+                            var multiple = [];
+                            function add(appt, list) {
+                                for (var i = 0; i < list.length; i++) {
+                                    multiple.push({
+                                        module: "calendar",
+                                        action: "confirm",
+                                        id: appt.id,
+                                        folder: appt.folder_id,
+                                        timestamp: reply2.timestamp,
+                                        data: list[i]
+                                    });
+                                }
+                            }
+                            for (var i = 0; i < reply.data.length; i++) {
+                                var a = reply.data[i];
+                                if (a.confirmations) add(a, a.confirmations);
+                                if (a.users) add(a, a.users);
+                            }
+                            ox.JSON.put(
+                                AjaxRoot + "/multiple?session=" + session,
+                                multiple, function() {
+                                    ox.Configuration.info(
+                                        _("Update successful"));
+                                });
+                        }
+                    }
+                );
+            };
+        }
+		
 		// get frame
 		var ih = getFrameElement("mail." + view.name + ".detail.content");
 		var ihf = ih;
