@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Stefan Preuss <stefan.preuss@open-xchange.com>
@@ -34,7 +34,7 @@ var cb_initAddressBook = null;
 
 //not valid for all circumstances but sufficient here
 function isSafari() { return navigator.userAgent.indexOf("AppleWebKit") >= 0; }
-function isFirefox() { return navigator.appName == "Netscape"; }
+function isFirefox() { return navigator.userAgent.indexOf('Gecko') > -1 && navigator.userAgent.indexOf('KHTML') === -1; }
 
 /**
  * callback when tinyMCE get initialized
@@ -55,7 +55,8 @@ function cb_initTiny(inst) {
 		tdContent[1].className="tiny_mceFirst";
 	}
 }
-
+	
+	
 /*
  * initialize tinyMCE editor 
  */
@@ -65,12 +66,12 @@ tinyMCE.init({
 	theme: "advanced",
 	editor_selector: "mceEditorOX",
 	language: (corewindow && configGetKey("language") ? configGetKey("language").substring(0,2) : "en"),		
-	plugins: "inlinepopups" + (configGetKey("modules.mail.spellcheck") == "true" ? ",spellchecker" : ""),
+	plugins: "inlinepopups,table,safari,paste" + (configGetKey("modules.mail.spellcheck") == "true" ? ",spellchecker" : ""),
 	content_css: getURL() + "css/mail/newmail.css",
 	
-	theme_advanced_buttons1: (editorEnabled ? "newdocument,|,bold,italic,underline,strikethrough,|,justifyleft,justifycenter,justifyright,justifyfull,|,fontselect,fontsizeselect,|,forecolor,backcolor" : "") ,
-	theme_advanced_buttons2: (editorEnabled ? "cut,copy,paste,|,bullist,numlist,|,outdent,indent,|,undo,redo,|,image,link,unlink,|,hr,|,charmap,|,blockquote" + (configGetKey("modules.mail.spellcheck") == "true" ? ",|,spellchecker" : "") : "") ,
-    theme_advanced_buttons3: "",
+	theme_advanced_buttons1: (editorEnabled ? "newdocument,|,bold,italic,underline,strikethrough,|,justifyleft,justifycenter,justifyright,justifyfull,|,formatselect,fontselect,fontsizeselect,|,forecolor,backcolor" : "") ,
+	theme_advanced_buttons2: (editorEnabled ? "cut,copy,paste,pastetext,pasteword,|,bullist,numlist,|,outdent,indent,|,undo,redo,|,image,link,unlink,|,hr,|,charmap,|,blockquote" + (configGetKey("modules.mail.spellcheck") == "true" ? ",|,spellchecker" : "") : "") ,
+    theme_advanced_buttons3: ((editorEnabled && configGetKey("gui.mail.editor_featureset") == 2) ? "tablecontrols,|,sub,sup,|,print|,ltr,rtl" : ""),
 	theme_advanced_toolbar_location: "top",
 	theme_advanced_toolbar_align: "left",
 	theme_advanced_resize_horizontal: false,
@@ -106,6 +107,7 @@ tinyMCE.init({
 	font_size_style_values : "8pt,10pt,12pt,14pt,18pt,24pt,36pt",
 	
     setup: function(ed) {
+		// key: enter
 		ed.onKeyDown.add(function(ed, e) {
 			// pressed enter?
 			if ((e.keyCode || e.which) == 13) {
@@ -157,7 +159,8 @@ function insidePresetContent(range) {
 			range.parentElement() : range.commonAncestorContainer;
 	// climb up until reaching the body node
 	// nodeName is always given in upper case letters
-	while (container.nodeName != "BODY") {
+	// check for "container" as well (bug #15435; Safari loses cursor after paste)
+	while (container && container.nodeName != "BODY") {
 		// found preset content?
 		if (container.id == "mcePresetContent") return true;
 		// climb up
@@ -218,7 +221,7 @@ function splitContent_W3C(ed) {
 	// do magic
 	var container = range.commonAncestorContainer;
 	var lastBR = null;
-    while (container.nodeName != "BODY") {
+    while (container && container.nodeName != "BODY") {
     	// set range to end of container
         range.setEndAfter(container);
         // get parent node
@@ -427,8 +430,18 @@ function newMailOnload() {
 	action = url["action"];
 	
 	if (corewindow && corewindow.mail_accounts) {
-		var id = url["folder"] && url["folder"].length != 0 ? url["folder"] : "default0/INBOX";
-		activeMailAccount = corewindow.mail_accounts.data.get(corewindow.getMailAccountIdByFolder(id));
+		var acc =  "default0/INBOX";
+		if (url["account"]) {
+			acc = url["account"];
+		} else {
+			if (url["folder"] && url["folder"].length != 0) {
+				acc = url["folder"];
+			} else if (url["id"] && url["id"].length != 0) {
+				acc = url["id"];
+			}
+			corewindow.getMailAccountIdByFolder(acc)
+		}
+		activeMailAccount = corewindow.mail_accounts.data.get(acc);
 	}
 		
 	/*
@@ -573,7 +586,7 @@ function cb_deleteAttachments() {
 register("setSignature", cb_setSignatureText);
 function cb_setSignatureText(obj, autoScroll) {
 
-    // adjust parameter
+	// adjust parameter
     var autoScroll = typeof autoScroll == "undefined" ? true : autoScroll;
     
 	// shortcut to active editor / body
@@ -595,7 +608,7 @@ function cb_setSignatureText(obj, autoScroll) {
 	ae.dom.remove('mceSignatureBottom');
 	
 	// position == "none"? (obj is null if no signature is selected)
-	if (!obj) return;
+	if (!obj) { return; }
 	
 	// prepare signature
 	// replace newlines in signature
@@ -603,7 +616,9 @@ function cb_setSignatureText(obj, autoScroll) {
 	var signature_text = replaceLeadingSpaces(obj.signature_text);
 	
 	// position?
-	switch(obj.position) {
+	var tmpPos = (action == "new" || typeof action == "undefined") ? "below" : obj.position;
+	// always "below" for new mails (see bug #15111), for example, when sending an infostore link
+	switch(tmpPos) {
 	
 		case "above":
 			// add preceding BR
@@ -1035,7 +1050,13 @@ function setMessageText(attachments) {
     	replaceEditorContent(mceDummy + presetContent);
 	
 		// add default signature
-		cb_setSignatureText(configGetKey("gui.mail.signatures")[defaultSignature], false);
+    	var signature = configGetKey("gui.mail.signatures")[defaultSignature];
+    	if (signature) {
+    		cb_setSignatureText(signature, false);
+    	} else {
+    		// add newline once - prevents firefox cursor bux
+    		addBeforeOrBottom(ae, createNewLine(ae, "mceNewlinePreserve"));
+    	}
 	}
 	
 	// reselect all content and reset cursor position to top
@@ -1098,11 +1119,17 @@ function setInitialFocus() {
 
 function firefox_setInitialFocus() {
 	var ae = tinyMCE.activeEditor;
-	ae.getWin().focus();
+	//ae.getWin().focus(); // Commented for bug fix #1536 (large blinking cursor in FF; cp. bug fix #14483)
 	if (ae.getWin().getSelection) {
 		var sel = ae.getWin().getSelection();
 		// 	select dummy node
 		var dummy = ae.dom.select('#mceDummy span')[0];
+		if (!dummy) {
+			// select very first element
+			dummy = ae.dom.select('body > *')[0];
+			// added for drafts which might no longer contain #mceDummy
+			// otherwise a large blinking cursor appears and stays visible until first keystroke
+		}
 		if (dummy) {
 			var range = sel.getRangeAt(0);
 			// set range & collapse
@@ -1111,7 +1138,7 @@ function firefox_setInitialFocus() {
 			// now the cursor position is correct
 		}
 	}
-	// switch window focus back and forth
+	// switch window focus back and forth (bug fix #14483)
 	window.focus();
 	ae.getWin().focus();
 	// now the cursor appearance is fine
