@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2003-2007 Open-Xchange, Inc.
+ * Copyright (C) 2003-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Jan Finsel <jan.finsel@open-xchange.com>
@@ -258,14 +258,31 @@ function initDisplay(view,elementid,setwidth) {
 	}
 	dynamiccontents[views[0]].push(tmp);
 }
-function changeDisplay(name,id) {
-	registerView(name,function() {  
-			showNode(id);
-		},null,null,
-		function() {  
-			hideNode(id);
-		});
-	}
+
+/**
+ * Shows or hides a menu element in the specified view.
+ * @param {String} name The name of the view as used for registerView.
+ * @param {String} id The ID of the DOM node which will be shown in the view.
+ * @param {Boolean} hide If true, a previously shown element will be hidden.
+ */
+function changeDisplay(name, id, hide) {
+    var key = name + "\x00" + id;
+    if (hide) {
+        var change = changeDisplay.changes[key];
+        if (change) {
+            change.view.show[change.index] = undefined;
+            change.view.hide[change.index] = undefined;
+        } else {
+            console.error("Invalid changeDisplay", name, id);
+        }
+    } else {
+        var v = registerView(name, function() { showNode(id); },
+            null,null, function() { hideNode(id); });
+        changeDisplay.changes[key] = { view: v, index: v.show.length - 1 };
+    }
+}
+changeDisplay.changes = {};
+
 /*** Global ***/
 changeDisplay("portal","menu_picture");
 changeDisplay("portal","menu_portal_quick_settings");
