@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Viktor Pracht <viktor.pracht@open-xchange.com>
@@ -182,7 +182,9 @@ var loadedModules = {
     interfaces: true,
     mail: true,
     mailaccount: true,
+    messaging: true,
     portal: true,
     tasks: true,
-    themes: true    
+    themes: true,
+    folderstorage: true
 };
