@@ -170,8 +170,6 @@ function rebuildTree() {
 	}
 	if(configGetKey("modules.calendar.module")) {
 		addHideTreeNode($("calendarTeamDay"),$("contentarea"));
-		addHideTreeNode($("calendarTeamWeek"),$("contentarea"));
-		//addHideTreeNode($("calendarDay"),$("contentarea"));
 		addHideTreeNode($("calendarWorkweek"),$("contentarea"));
 		addHideTreeNode($("calendarWeek"),$("contentarea"));
 		addHideTreeNode($("calendarMonth"),$("contentarea"));
@@ -197,6 +195,9 @@ function rebuildTree() {
 	if(configGetKey("modules.infostore.module") || configGetKey("modules.mail.module")) {
 		addHideTreeNode($("mailCheck"),$("below_folders"));
 	}
+	if (configGetKey("modules.messaging.module")) {
+	    addHideTreeNode($("messaging"), $("contentarea"));
+	}
 	addHideTreeNode($("folder_props"),$("contentarea"));
 	addHideTreeNode($("config"),$("configComplete"));
 	addHideTreeNode($("config_tags"),$("configComplete"));
