@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Markus Wagner <markus.wagner@open-xchange.com>
@@ -454,7 +454,7 @@ Participants.prototype = {
 					i18n: true,
 					sortable: true,
 					width: "30%",
-					set: function(div, text){
+					set: function(div, text){					
 						removeChildNodes(div);
 						var dn = text[2] || text[5] || _("unknown"); /*i18n*/
 						if(text[6] == "groupMember"){
@@ -995,7 +995,7 @@ Participants.prototype = {
 		if(this.showUser){
 			oRequestObj['module'] = "contacts";
 			oRequestObj['action'] = "search";	
-			oRequestObj['columns'] = "1,20,500,555,602,524,556,557";	
+			oRequestObj['columns'] = "1,20,500,555,602,524,556,557,501,502";	
 			oRequestObj['sort'] = "500";
 			oRequestObj['order'] = "asc";
 			oRequestObj['data'] = userPatternObj;
@@ -1032,10 +1032,19 @@ Participants.prototype = {
 								continue; 
 							}
 							
+							var displayname = "";
+							if (cb[2]) {
+								displayname = cb[2];
+							} else if (cb[8] || cb[9]) {
+								displayname = (cb[9] || "") + ", " + (cb[8] || ""); 
+							} else {
+								displayname = cb[3];
+							}
+							
 							if (!cb[3] && !cb[6] && !cb[7] && configGetKey("participants.showWithoutEmail")) {
 								// contact do not have any e-mail address but config says show it anyway
-								// but we just want to have it once
-								tmpArray.push(["contact_" + cb[0], cb[1], cb[2], null, cb[5], 0]);
+								// but we just want to have it once								
+								tmpArray.push(["contact_" + cb[0], cb[1], displayname, null, cb[5], 0]);
 							} else {
 								function isUser(user) {
 									return user && user > 0;
@@ -1045,8 +1054,9 @@ Participants.prototype = {
 								for (var ia=0; ia<3; ia++) {
 									var mailaddr = cb[[ 3, 6, 7][ia]];
 									// do not add if noaddress available
-									if (!mailaddr) continue; 									
-									tmpArray.push([( isUser(cb[5]) ? "user_" : "contact_") + cb[0], cb[1], cb[2], mailaddr, cb[5], ia]);
+									if (!mailaddr) continue; 
+									
+									tmpArray.push([( isUser(cb[5]) ? "user_" : "contact_") + cb[0], cb[1], displayname, mailaddr, cb[5], ia]);
 									// we don't want all of the users addresses so we
 									// break after adding the first one
 									if (!Self.allEmailAddresses) break;
@@ -1286,14 +1296,25 @@ Participants.prototype = {
 		var cb_fetch_contacts = joint.add(function(data) {
 			var tmpArray = new Array();
 			// loop objects
-			for(i = 0; i < data.objects.length; i++) {
+			for(i = 0; i < data.objects.length; i++) {				
 				// shortcut
 				var item = data.objects[i];
+							
 				// needed later to map email addresses
 				var map_item = collection_contact.objects[i];				
 				
 				// look for email address
 				item.email = item.email1 || item.email2 || item.email3;
+				
+				// setting a valid display name, if not given (bug #
+				if (!item.display_name) {
+					if (item.last_name || item.first_name) {
+						item.display_name = (item.last_name || "") + ", " + (item.first_name || "");
+					} else {
+						item.display_name = item.email;
+					}
+				}
+				
 				// add
 				tmpArray.push([
 						        "contact_" + item.id, item.folder_id,
