@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Viktor Pracht <Viktor.Pracht@open-xchange.org>
@@ -31,8 +31,13 @@ temporary.MakeList.addIcon = function(icon) {
         width: icon.width,
         style: { padding: 0, textAlign: "center" },
         set: function(div, data) {
-            var src = getFullImgSrc(icon.isVisible(data) ?
-                icon.getIcon(data) : "img/dummy.gif");
+            if (icon.isVisible(data)) {
+                var src = icon.getIcon(data);
+                src = src.charAt(0) == "/" ? src.substring(1)
+                                           : getFullImgSrc(src); 
+            } else {
+                var src = getFullImgSrc("img/dummy.gif");
+            }
             if (!div.firstChild) {
                 div.appendChild(newnode("img", 0, { src: src }));
             } else {
