@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Suphi Basdemir <suphi.basdemir@open-xchange.com>
@@ -162,7 +162,7 @@ SearchListAddressBook.prototype = {
 		if(!json)
 		var json = new JSON();
 		this.distrids = [];
-		json.put(AjaxRoot + "/contacts?action=search&session=" + corewindow.session + "&columns=1,500,555,556,557,524,602,592",
+		json.put(AjaxRoot + "/contacts?action=search&session=" + corewindow.session + "&columns=1,500,555,556,557,524,602,592,501,502",
 			Self.searchObject,
 			null,
 			function(findContactForDistrList) {	
@@ -175,6 +175,8 @@ SearchListAddressBook.prototype = {
 				 * 5 = internal_userid  (524)
 				 * 6 = mark_as_distri.  (602)
 				 * 7 = distribution_l.  (592)
+				 * 8 = first name
+				 * 9 = last name
 				 */
 				
 				/* click on "Go" for search in the Addressbook */
@@ -211,7 +213,13 @@ SearchListAddressBook.prototype = {
 							}
 						} else {
 							/* the flag in [index 6] is false, so this contact is not a distribution list  */
-							var displayName = Self.findContactForDistrList.data[i][1] || "";
+							var displayName = "";
+							if (Self.findContactForDistrList.data[i][1]) {
+								displayName = Self.findContactForDistrList.data[i][1];
+							} else if (Self.findContactForDistrList.data[i][8] || Self.findContactForDistrList.data[i][9]) {
+								displayName = (Self.findContactForDistrList.data[i][9] || "") + ", " 
+									+ (Self.findContactForDistrList.data[i][8] || "");
+							}
 							
                             var findEmails = 0;
 							if(Self.findContactForDistrList.data[i][2]) {
