@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -57,6 +57,12 @@ function cFolderTree(DOMNode, actionTree, enableDND,cache_param,state)
 		}
 	};
 											
+	if (IE < 8 && !this.dom_node.style.position) {
+	    this.dom_node.style.position = "relative";
+        this.dom_node.style.overflowX = "hidden";
+	    this.dom_node.style.overflowY = "scroll";
+	}
+	
 	this.tree.events.register ("OX_Tree_Expand",function (node,fn_opt){Self.expand_node(node,fn_opt);});
 	this.tree.events.register ("OX_Tree_Node_Click",Self.action_node);
 	this.tree.events.register('OX_Tree_State_Changed',function (){Self.saveConfiguration();});
@@ -220,9 +226,10 @@ load : function (){
 	{
 		this.cache.load_folders(this.state,new Join(function (){
             if (Self.cache.GALPresent === undefined) {
-                (new JSON).get(AjaxRoot +
-                    "/folders?action=list&all=1&columns=1&parent=2&session=" +
-                    session, null, function(response) {
+                (new JSON).get(AjaxRoot 
+                	+ "/folders?action=list&all=1&columns=1&parent=2"
+                    + (configContainsKey("modules.folderstorage") ? "&tree=1" : "")
+                    + "&session=" + session, null, function(response) {
                         Self.cache.GALPresent = false;
                         for (var i = 0; i < response.data.length; i++) {
                             if (response.data[i][0] == 6) {
@@ -1057,6 +1064,9 @@ SubscribeFolder.addChangedItem = function(item) {
 	}
 	item["module"] = "folder";
 	item["action"] = "update";
+	if (configContainsKey("modules.folderstorage")) {
+		item["tree"] = "1";
+	}
 	SubscribeFolder.changedFolders.push(item);
 }
 SubscribeFolder.saveChanges = function () {
