@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -207,6 +207,16 @@ function getIconImagePath(sParentId, sId, sModule, bLink, bREnabledIMAP, bDefaul
 	
 	return sImageSRC;			
 }
+ 
+function getFolderOwner(folder) {
+	var owner = config.identifier;
+	var _tmpF = oMainFolderTree.cache.find_folder(folder);
+ 	if (_tmpF && (_tmpF.oxfolder.data.type == 1 || _tmpF.oxfolder.data.type == 3) && 
+ 	    _tmpF.oxfolder.data.created_by) {
+ 		owner = _tmpF.oxfolder.data.created_by;
+ 	}
+ 	return owner;
+}
 
 /**
  * Fetch folder information using multiple request
@@ -227,6 +237,7 @@ function doAjaxFetchFolder(folderIDs, columns, callback) {
 function doAjaxUpdateRequest(sId, oFolder, nTimeStamp, callback, err_handlr) {
 	var sAjaxRequest = AjaxRoot + "/folders?action=update"
         + "&id=" + getUrlEncodedString(sId)
+        + (configContainsKey("modules.folderstorage") ? "&tree=1" : "")
         + "&session=" + session
 	if (nTimeStamp != undefined) {
 		sAjaxRequest += "&timestamp=" + nTimeStamp;
@@ -237,13 +248,16 @@ function doAjaxUpdateRequest(sId, oFolder, nTimeStamp, callback, err_handlr) {
 function doAjaxNewFolderRequest(parentNodeId ,oFolder, callback, callbackERR) {
     var sAjaxRequest = AjaxRoot + "/folders?action=new"
        + "&folder_id=" + getUrlEncodedString(parentNodeId) 
+       + (configContainsKey("modules.folderstorage") ? "&tree=1" : "")
        + "&session=" + session;
     newFolderJson.put(sAjaxRequest, oFolder, null, callback, callbackERR);        
 }
 
 function doAjaxRemoveFolderRequest(aFolders, nTimeStamp, callback) {
-    var sAjaxRequest = AjaxRoot + "/folders?action=delete&session=" + session;
-    if (nTimeStamp != undefined) {
+    var sAjaxRequest = AjaxRoot + "/folders?action=delete"
+    			+ (configContainsKey("modules.folderstorage") ? "&tree=1" : "")
+    			+ "&session=" + session;
+    if (nTimeStamp != undefined) {    	
         sAjaxRequest += "&timestamp=" + nTimeStamp;
     }
     newFolderJson.put(sAjaxRequest, aFolders, null, callback);  
