@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Andreas Mayer <andreas.mayer@open-xchange.com>
@@ -69,14 +69,22 @@ function loadFolderTree(stateTree,nSelectedIdStorage) {
     register("OX_Dummy", fn_subfolder_keyHandler);
 	
     var submenu = new PopupMenu();
+    
     var PIM = { calendar: 1, tasks: 1, contacts: 1, system: 1 };
+    var mail = { mail: 1 };
+    if (configContainsKey("modules.folderstorage")) {
+    	PIM["mail"] = 1;
+    	mail = PIM;
+    }
     var items = {
-        mail:      { name: "E-Mail"    /*i18n*/, when: { mail: 1 } },
+        mail:      { name: "E-Mail"    /*i18n*/, when: mail },
         calendar:  { name: "Calendar"  /*i18n*/, when: PIM },
         tasks:     { name: "Tasks"     /*i18n*/, when: PIM },
         contacts:  { name: "Contacts"  /*i18n*/, when: PIM },
         infostore: { name: "InfoStore" /*i18n*/, when: { infostore: 1 } }
     };
+    
+    
     for (var i in items) (function(type) {
         var def = items[type];
         var key = "modules." + type + ".module";
