@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2008 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Viktor Pracht <viktor.pracht@open-xchange.com>
@@ -278,13 +278,17 @@ var toggleCollapsedPanel = emptyFunction;
 
     function switchModule(name) {    	
         if (active_module == name) return;
-        images[active_module].collapsed.src =
-            images[active_module].expanded.src =
-            module_icons[active_module].getPath(false);
-        images[name].collapsed.src = images[name].expanded.src =
-            module_icons[name].getPath(true);
-        divs[active_module].className = "";
-        divs[name].className = "background-color-PMG-selection-elements";
+        if (images[active_module]) {
+            images[active_module].collapsed.src =
+                images[active_module].expanded.src =
+                module_icons[active_module].getPath(false);
+            divs[active_module].className = "";
+        }
+        if (images[name]) {
+            images[name].collapsed.src = images[name].expanded.src =
+                module_icons[name].getPath(true);
+            divs[name].className = "background-color-PMG-selection-elements";
+        }
         active_module = name;
         
         if (active_module == "configuration") {
