@@ -6,7 +6,7 @@
  * 
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  * 
- * Copyright (C) 2004-2007 Open-Xchange, Inc.
+ * Copyright (C) 2004-2010 Open-Xchange, Inc.
  * Mail: info@open-xchange.com 
  * 
  * @author Dirk Hartmann <dirk.hartmann@open-xchange.com>
@@ -295,9 +295,9 @@ function() {
         }
     }
     
-    function cb_object_changed() {
-        (tasksSelection2.getSelected(), true);
-    }
+//    function cb_object_changed() {
+//        (tasksSelection2.getSelected(), true);
+//    }
     
     function switchToTaskStdView() {
         triggerEvent("OX_Switch_View", configGetKey("gui.tasks.view"));
@@ -385,7 +385,7 @@ function() {
             } else {
                 return { "percent_completed": 100, "status": 3 };
             }
-        }       
+        }
         tasks_udpateTasks(tasksSelection2.getSelected(), ["percent_completed"], cb_changes);
     }
     
@@ -414,15 +414,15 @@ function() {
                     var object = daten.objects[i];
                     var timestamp = object["timestamp"] || 0;
                     changes = cb_changes(object);                    
-                    if (!changes) continue ; 
-                    fOCData = changes;               
+                    if (!changes) continue;
+                    fOCData = changes;
                     fPutData.push({
                         "action": "update",
                         "module": "tasks",
                         "folder": object["folder_id"],
                         "id": object["id"],
                         "timestamp": object["timestamp"] || 0,
-                        "data" : fOCData                
+                        "data" : fOCData
                     });
                 }
                 if (!fPutData.length || fOCData == null) return;
