@@ -9,6 +9,12 @@ oMainFolderTree.checkGAL(function(GAL) {
     page = new ox.Configuration.VSplit(node, _("Group Administration"),
                                            0.5);
     page.init = initPage;
+    
+    // directlink access to this module
+    if(window.location.hash=="#view=configuration/admin/groups"){
+        node.click();
+    }
+
 });
 
 function initPage() {
@@ -17,16 +23,21 @@ function initPage() {
         {
             text: _("Group name"),
             index: "name",
+            id: "name",
+            sortable: true,
             width: "50%",
             clear: LiveGrid.makeClear(""),
             set: LiveGrid.defaultSet
         }, {
             text: _("Display name"),
             index: "display_name",
+            id: "display_name",
+            sortable: true,
             clear: LiveGrid.makeClear(""),
             set: LiveGrid.defaultSet
         }
     ], selection);
+    grid.sort = LiveGrid.localSort;
     grid.emptylivegridtext = _("No groups available");
     page.list = grid;
     var mapping = {};
@@ -52,6 +63,7 @@ function initPage() {
             storage.remove(0, storage.ids.length);
             storage.append(reply.data);
             grid.enable(storage);
+            grid.setSort(grid.sort_id, grid.sort_order);
         }
     };
     page.load = function(cont) {
