@@ -689,7 +689,7 @@ if (args.newhtml) {
         "contacts/newContact": 0, "contacts/newDistributionList": 0,
         "mail/newMail": 0, "mail/detailMail": 0,
         "infostore/newInfoItemHidden": 0, "popup_trigger_cb": 0,
-        "infostore/newInfoItemMain": 0
+        "infostore/newInfoItemMain": 0, "messaging/messaging": 1
     };
     
     var depsFile = new File(args.dest + "/deps.js");
@@ -724,5 +724,6 @@ if (args.newhtml) {
     processXSLT("newInfoItemHidden", "html/infostore", "init", "");          
     processXSLT("popup_trigger_cb", "html", "init", "");  
     processXSLT("newInfoItemMain", "html/infostore", "init", "");
+    processXSLT("messaging", "messaging", "preload", "messaging");
 }
 /*end*/
\ No newline at end of file
